
% Dogmatic interpretation of 5.8.7 and 5.8.8 to find design capacities. 
% Linear design.

%------Geometry----------------------------------------------------------%
L=3800; %mm Length of column 
h=150; %mm y-direction
b=240; %mm z-direction
d=h-33; %mm, y-direction eff height
e1y=40; %mm eccentricity
Ac=h*b; %mm^2 Area of concrete
dsteel=14; %mm R14
As=4*pi*dsteel^2/4; %mm^2 Reinforcement area
h_1=h-2*33; %mm dist between reinforcement

column = input('Choose column; \n1 for column A \n2 for column B\n ');

%------Reaction forces---------------------------------------------------%
N_Ed = 0:1000:1000000;%Newton
M0Ed = N_Ed*e1y; %Constant first order moment
%------------------------------------------------------------------------%
%------Material----------------------------------------------------------%
%CONCRETE
alfa_cc=1; %Equals 1 if no national annex
gamma_c=1.5; %PSF concrete
gamma_cE=1.2; %PSF Ec
phi_ef=0; % Neglecting the effects of creep

%Concrete values and formulas from EC2-1-1, tab 3.1 if nothing else stated
if column==1
% Column A - C45/55
    fck=45; %MPa                                    
    fcm=53; %MPa, Eurocode mean
    Ecm=36*10^3; %MPa
    Ecd=Ecm/gamma_cE; %MPa, 5.8.6(3)
    epc3=0.00175;
    epcu3=0.0035;
    n=2;
    fcd=alfa_cc*fck/gamma_c; %MPa, 3.1.6(1)
    etta = 1; % reduction factor fcd, 3.1.7(3)                         
    lam = 0.8; % reduction factor compression zone, 3.1.7(3)
    columnname='A';
elseif column==2
% Column B - C100/115    
    fck=100; %MPa 
    fcm=fck+8; %MPa, Eurocode mean
    Ecm=(22*(fcm/10)^0.3)*10^3; %MPa  
    Ecd=Ecm/gamma_cE; %MPa, 5.8.6(3)
    epc3=(1.75+0.55*((fck-50)/40))/1000; 
    epcu3=(2.6+35*((90-fck)/100)^4)/1000; %bilinear (fig 3.4)
    n=1.4+23.4*((90-fck)/100)^4; 
    fcd=alfa_cc*fck/gamma_c; 
    etta = 1 - (fck-50)/200; % reduction factor fcd (EC2 3.1.7(3))         
    lam = 0.8-(fck-50)/400; % reduction factor av compression zone (EC2 3.1.7(3))
    columnname='B';
else
    error('Invalid input')
end

%STEEL B500B(R10505)
gamma_s=1.15; %tab 2.1N
fyk=500; %MPa
fyd=fyk/gamma_s; %MPa
epyuk=0.05; %EC2-1 Table C.1 
epyud=0.9*epyuk;
k_y=1.08; %EC2-1 Table C.1
Es=200*10^3; %MPa
roh_s=7850; %kg/m^3 Density
eyd=fyd/Es;
eyk=fyk/Es;
euk=5*10^-2; %Ultimate reinforcement strain
%------------------------------------------------------------------------%
%------Slenderness--------------------------------------------------------%
%Assuming column is slender (criterion in EC2-1, 5.8.3.1)
%EC2-1, 5.8.3.2:
l0 = L; %mm, effective length when column assumed to be pinned
i = h/sqrt(12); %mm
lambda=l0/i;
%-------------------------------------------------------------------------%



