%-----------Fetching material parameters-------------%
Material_and_geometry
%----------------------------------------------------%
%EC2-1, 5.8.3.1:
omega=(As*fyd)/(Ac*fcd); %mech. reinforcement relation
n_rel=N_Ed./(Ac*fcd); %Relative normal force   

%------NOMINAL STIFFNESS------------------------------------------%
Ic = b*h^3/12; %mm4, 2nd moment of area of concrete section
ey = 42; %mm, distance to area center from reinforcement 
Is = 4*(1/4)*pi*(dsteel/2)^4+ey^2*As; %mm4, 2nd moment of area reinforcement

% 5.2.7.2(2):
k1 = sqrt(fck/20); 
k2 = n_rel.*lambda/170;
k2(k2 > 0.2) = 0.2;

Ks = 1;
Kc = k1*k2/(1+phi_ef);

% Simplified method, 5.2.7(3):  
Ks_simp = 0;
Kc_simp = 0.3/(1+0.5*phi_ef);

% Nominal stiffness, 5.8.7.2(1):
EI = Kc*Ecd*Ic + Ks*Es*Is;
EI_simp = Kc_simp*Ecd*Ic + Ks_simp*Es*Is;

% Moment magnification factor, 5.8.7.3:
% 5.8.7.3(2):
c0 = 8; % distribution of 1st order moment (constant)
beta = pi^2/c0; %sinus shaped 2nr order moment

% 5.8.7.3(1):
%Euler Buckling loads:
Nb = pi^2*EI/l0^2; Nb_simp = pi^2*EI_simp/l0^2;
%Total design moment
MEd_stiffness = M0Ed.*(1+beta./((Nb./N_Ed)-1));
MEd_stiffness_simp = M0Ed.*(1+beta./((Nb_simp./N_Ed)-1));
%-----------------------------------------------------------------%
%------NOMINAL CURVATURE------------------------------------------%
% Kr, correction factor axial force, 5.8.8.3(2):
n_bal = 0.4;
n_u = 1 + omega;
Kr = (n_u-n_rel)./(n_u-n_bal);
Kr(Kr>1)=1;
% Kphi, factor conserning creep, 5.8.8.3(4):
beta_creep = 0.35 + fck/200 - lambda/150;
Kphi = 1 + beta_creep*phi_ef;
Kphi(Kphi<1)=1;

% Curvature, 5.8.8.3:
r0=(0.45*d)/eyd;
r=r0./(Kr.*Kphi);

% Nominal 2nd order moment, 5.8.8.2(3):
e2 = l0^2./(r.*c0); %Second order deflection
M2 = N_Ed.*e2;

% Design bending moments, 5.8.8.2(1):
MEd_curv = M0Ed + M2;
%-----------------------------------------------------------------%
%-----------For simpler plotting in MN-diagram -------------%
MEd_c = MEd_curv*10^-6;
MEd_s1 = MEd_stiffness*10^-6;
MEd_s2 = MEd_stiffness_simp*10^-6;
NEd = N_Ed*10^-3;