%--------Fetching work diagram and material parameters---------%
Work_diagram
%--------------------------------------------------------------%
es = [-epyu:0.0001:0.95*epcu] ;%Strain in tensile reinforcement

N_rd = zeros(length(es),1);
M_rd = zeros(length(es),1);

%---MN-diagram with nonlinear constitutive relation for concrete stress---%
for i = 1:length(es)
    h_virt = epcu*(h+h_1)/(2*(epcu-es(i))); %Virtual length points of maximum (positive) and zero strain
   %---------------Calculating strains and stresses---------------------------%
    a = es(i);
    %-------------Normal force and moment pr.length-----------------------%
    N_c1 = @(y) (((k_c*((0+(epcu-0)/h_virt.*(y-(h/2-h_virt))))./epc-(((0+(epcu-0)/h_virt.*(y-(h/2-h_virt))))./epc).^2).*fc./(1+(k_c-2).*((0+(epcu-0)/h_virt.*(y-(h/2-h_virt))))./epc))).*b;
    M_c1 = @(y) (((k_c*((0+(epcu-0)/h_virt.*(y-(h/2-h_virt))))./epc-(((0+(epcu-0)/h_virt.*(y-(h/2-h_virt))))./epc).^2).*fc./(1+(k_c-2).*((0+(epcu-0)/h_virt.*(y-(h/2-h_virt))))./epc))).*b.*y;
    %---------------------------------------------------------------------%
    es_top = epcu*(h_virt-h/2+h_1/2)/h_virt; %Strain in compression reinforcement
           if h_virt <= h  %The compression zone height is within the cross section 
               M_Nc = integral(M_c1,(h/2-h_virt),h/2);%Momentcontribution from concrete
               Nc = integral(N_c1,(h/2-h_virt),h/2); %Integrated normal force in concrete
                    %---Determining stresses in reinforcement-------------%                 
                    %---Top reinforcement---%
                    if abs(es_top) <= ey
                        sigma_top = es_top*Es;
                    else
                        if es_top <= 0
                         sigma_top = -((fy+((k_y*fy-fy)/(epyu-ey))*(abs(es_top)-ey)));
                        else
                         sigma_top = ((fy+((k_y*fy-fy)/(epyu-ey))*(abs(es_top)-ey)));
                        end
                    end
                    %-----------------------%
                    %--Bottom reinforcement-%
                    if abs(es(i)) <= ey
                        sigma_bot = es(i)*Es;
                    else
                        if es(i) <= 0 
                            sigma_bot = -((fy+((k_y*fy-fy)/(epyu-ey))*(abs(es(i))-ey)));
                        else 
                            sigma_bot = ((fy+((k_y*fy-fy)/(epyu-ey))*(abs(es(i))-ey)));
                        end
                    end
                    %-----------------------%
                    %-----------------------------------------------------%
           else  %The compression zone height exceeds the cross sectionial height
               M_Nc = integral(M_c1,-h/2,h/2);%Moment from concrete
               Nc = integral(N_c1,-h/2,h/2);%Integrated normal force in concrete
               %------Determining stresses in reinforcement---------------%
               %---Top reinforcement---%
               if abs(es_top) <= ey
                        sigma_top = es_top*Es;
                    else
                        if es_top <= 0
                         sigma_top = -((fy+((k_y*fy-fy)/(epyu-ey))*(abs(es_top)-ey)));
                        else
                         sigma_top = ((fy+((k_y*fy-fy)/(epyu-ey))*(abs(es_top)-ey)));
                        end
               end
               %-----------------------%
               %---Bottom reinforcement---%
               if abs(es(i)) <= ey
                    sigma_bot = es(i)*Es;
               else
                    if es(i) <= 0 
                       sigma_bot = -((fy+((k_y*fy-fy)/(epyu-ey))*(abs(es(i))-ey)));
                    else 
                       sigma_bot = ((fy+((k_y*fy-fy)/(epyu-ey))*(abs(es(i))-ey)));
                    end
               end
               %--------------------------%      
           end
    %---------------------------------------------------------------------%            
    %----------Force equilibrium------------------------------------------%
            Ns_top = sigma_top*As/2; %Axial force in compression reinforcement
            Ns_bunn = sigma_bot*As/2; %Axial force in tensile reinforcement
            N_rd(i) = Ns_top + Ns_bunn + Nc; %Axial force equilibrium
            M_rd(i) = Ns_top*(h_1/2) - Ns_bunn*(h_1/2)+M_Nc; %Moment equilibrium     
    %---------------------------------------------------------------------%        
   
end
M_rd = M_rd*10^-6;
N_rd = N_rd*10^-3;
%Plot tools:
%{
figure
MRd=10^-6*M_rd; NRd=10^-3*N_rd;
plot(MRd,NRd,'b');
x=xlabel('Moment [kNm]');
y=ylabel('Axial force [kN]');
axis([0 1.1*max(MRd) 0 max(NRd)]);      
hold on
grid on
grid minor

str = sprintf('MN-diagram and forces for column %s according to EC2 with %s', columnname, Materialmodelname);
t=title(str);

plot(MEd_s1,NEd,'r'); %for finere plot, plot bare positive moment (sjekk vektoren)
plot(MEd_s2,NEd,'r--'); %--II--
plot(MEd_c,NEd,'k');
l=legend('M-N-diagram','Nominal stiffness','Nominal stiffness, simplified','Nominal curvature');
set(x,'FontSize', 14);
set(y,'FontSize', 14);
set(l,'FontSize', 14);
set(t,'FontSize', 14);
hold off
%}

format long g
%Finding intersections, ie finding capacities:
[MRd_curvature,NRd_curvature]=intersections(M_rd,N_rd,MEd_c,NEd,0);
[MRd_stiffness,NRd_stiffness]=intersections(M_rd,N_rd,MEd_s1(1:381),NEd(1:381),0);
[MRd_stiffnesssimp,NRd_stiffnesssimp]=intersections(M_rd,N_rd,MEd_s2(1:381),NEd(1:381),0);

str = sprintf('Capacities for column %s according EC2 methods with %s: \nAxial force capacity; \nNominal curvature: %dkN \nNominal stiffness: %dkN, \nSimplified nominal stiffness: %dkN', columnname, Materialmodelname, round(NRd_curvature), round(NRd_stiffness), round(NRd_stiffnesssimp));
disp(str);  

%Saving to .txt-files:
%{
MN_nonlin='MN_nonlin.txt';
fileID=fopen(MN_nonlin,'w');
fprintf(fileID, '%10.2f %10.2f\n', [transpose(MRd); transpose(NRd)]);
fclose(fileID);

Curvature='Curvature.txt';
fileID=fopen(Curvature,'w');
fprintf(fileID, '%10.2f %10.2f\n', [transpose(MEd_c); transpose(NEd)]);
fclose(fileID);

Stiff='Stiff.txt';
fileID=fopen(Stiff,'w');
fprintf(fileID, '%10.2f %10.2f\n', [transpose(MEd_s1); transpose(NEd)]);
fclose(fileID);

Stiff_simp='Stiff_simp.txt';
fileID=fopen(Stiff_simp,'w');
fprintf(fileID, '%10.2f %10.2f\n', [transpose(MEd_s2); transpose(NEd)]);
fclose(fileID);
%}
