%only nonlinear relations for concrete

column = input('Choose column; \n1 for column A \n2 for column B\n ');
Materialmodel = input('Choose model:\n2 for EC1-1 design \n3 for EC1-1 mean \n4 for EC2-2 Global resistance factor method \n5 for insitu mean\n7 for Fib Model Code 2010 mean values\n');

%------Geometry----------------------------------------------------------%
L=3800; %mm Length of column 
h=150; %mm y-direction
b=240; %mm z-direction
d=h-33; %mm, y-direction eff height
e1y=40; %mm eccentricity
Ac=h*b; %mm^2 Area of concrete
dsteel=14; %mm R14
As=4*pi*dsteel^2/4; %mm^2 Reinforcement area
h_1=h-2*33; %mm dist between reinforcement

%------Reaction forces---------------------------------------------------%
N_Ed = 0:1000:1000000;%Newton
M0Ed = N_Ed*e1y; %Constant first order moment

%-------Material---------------------------------------------------------%
%CONCRETE
alfa_cc=1; %Equals one if no national annex from EC2-1-1
gamma_c=1.5; %PSF concrete
gamma_cE=1.2; %PSF concrete stiffness

cov_c=0.15;%Concrete coefficent of variation
cov_s=0.04;%Reinforcement steel coefficient of variation

phi_ef=0; % Neglecting the effects of creep

if column==1
% Column A - C45/55
    fck=45; %MPa                                    
    fcm=53; %MPa, Eurocode mean
    Ecm=36*10^3; %MPa
    Ecd=Ecm/gamma_cE; %MPa, 5.8.6(3)
    epc=0.0024;
    epcu=0.0035;
    n=2;
    fcd=alfa_cc*fck/gamma_c; %MPa, 3.1.6(1)
    lam = 0.8; % reduction factor compression zone, 3.1.7(3)
    k_c=1.05*Ecd*epc/fcd;
    columnname='A';
elseif column==2
% Column B - C100/115    
    fck=100; %MPa 
    fcm=fck+8; %MPa, Eurocode mean
    Ecm=(22*(fcm/10)^0.3)*10^3; %MPa  
    Ecd=Ecm/gamma_cE; %MPa, 5.8.6(3)
    epc=0.0028; %EC2-1 Tab 3.1
    epcu=(2.8+27*((98-fcm)/100)^4)/1000; %nonlinear (fig 3.2)
    n=1.4+23.4*((90-fck)/100)^4; 
    fcd=alfa_cc*fck/gamma_c; 
    lam = 0.8-(fck-50)/400; % reduction factor av compression zone (EC2 3.1.7(3))
    k_c=1.05*Ecd*epc/fcd;
    columnname='B';
else
    error('Invalid input')
end

%STEEL B500B(R10505)
gamma_s=1.15; %tab 2.1N
fyk=500; %MPa
fyd=fyk/gamma_s; %MPa
epyuk=0.05; %EC2-1 Table C.1 
epyud=0.9*epyuk;
k_y=1.08; %EC2-1 Table C.1
Es=200*10^3; %MPa
roh_s=7850; %kg/m^3 Density
eyd=fyd/Es;
eyk=fyk/Es;
euk=5*10^-2; %Ultimate reinforcement strain

if Materialmodel == 2 %EC2-1-1 general method - design                               
    fc=fcd;
    Ecd=Ecm/1.2;
    Ec=Ecd;
    fy=fyd;
    ey=eyd;
    epyu=epyud;
    k_c=1.05*Ec*epc/fc;
    
    Materialmodelname='EC2-1 general method design';

elseif Materialmodel == 3 %EC2-1 mean values - best estimate
    fc=fcm;
    Ec=Ecm;
    Ecd=Ec;
    fy=fyk;
    ey=eyk;
    epyu=epyuk;
    k_c=1.05*Ec*epc/fc;
    
    Materialmodelname='EC2-1 with mean values';

elseif Materialmodel == 4 %EC2-2 GRFM
    fc=1.27*fcd;
    Ec=22*10^3*(fc/10)^0.3;
    Ecd=Ec;                                         
    epc=(0.7*fc^0.31)*10^-3;
    epc(epc>2.8*10^-3)=2.8*10^-3;
    if column==2 
        epcu=(2.8+27*((98-fc)/100)^4)*10^-3;
    end
    fy=1.1*fyk;
    ey=fy/Es;
    epyu=epyuk;                                                 
    k_c=1.05*Ec*epc/fc;
    
    Materialmodelname='EC2-2 Global resistance factor method';
    
elseif Materialmodel==5 %insitu
    fc=(fck/1.15)*exp(1.645*cov_c);
    Ec=22*10^3*(fc/10)^0.3;
    Ecd=Ec;                     
    epc=(0.7*fc^0.31)*10^-3;
    epc(epc>2.8*10^-3)=2.8*10^-3;
    if column ==2
        epcu=(2.8+27*((98-fc)/100)^4)*10^-3;
    end
    fy=fyk*exp(1.645*cov_s);
    ey=fy/Es; 
    epyu=epyuk;
    k_c=1.05*Ec*epc/fc;
    
    Materialmodelname='insitu';
    
elseif Materialmodel==7 && column==1 %fib model code 2010       
    Ecm=21.5*10^3*(fcm/10)^(1/3); %MPa
    epc=2.5*10^-3;
    epcu=0.0035;
    n=2;
    fcd=alfa_cc*fck/gamma_c; %MPa
    
    fc=fcm;
    Ec=Ecm;
    Ecd=Ec/gamma_cE; 
    fy=fyk;
    ey=eyk; 
    epyu=epyuk;
    k_c=1.05*Ec*epc/fc;
        
    Materialmodelname='Fib Model Code 2010 mean values';
    
elseif Materialmodel==7 && column==2
    Ecm=21.5*10^3*(fcm/10)^(1/3); %MPa 
    epc=3*10^-3; 
    epcu=3*10^-3; 
    n=1.4+23.4*((90-fck)/100)^4; %EC2-1 Tab 3.1
    fcd=alfa_cc*fck/gamma_c; 
       
    fc=fcm;
    Ec=Ecm;
    Ecd=Ecm/gamma_cE; 
    fy=fyk;
    ey=eyk; 
    epyu=epyuk;
    k_c=1.05*Ec*epc/fc;
        
    Materialmodelname='Fib Model Code 2010 mean values';
    
end

%------Slenderness--------------------------------------------------------%
%Assuming column is slender (criterion in EC2-1, 5.8.3.1)
%EC2-1, 5.8.3.2:
l0 = L; %mm, effective length when column assumed to be pinned
i = h/sqrt(12); %[mm] radius of gyration
lambda=l0/i; %Slenderness ratio


