clear all
close all
clc
%fc = concrete compressive strength
%fy = steel yield strength
%N = axial force
%M = moment
syms fc fy N M positive
%-------MATERIAL----------------------------------------------------------%
%Concrete-----------------------------------------------------------------%
fck=45; epcu3=0.0035; Ec= 22*(fc/10)^0.3*1000;
COV_c = 0.15; mu_c = (fck/1.15)*exp(1.645*COV_c); sigma_c=mu_c*COV_c;
mu_logc=log((mu_c^2)*sqrt(1/(sigma_c^2+mu_c^2))); %Lognormal mean
sigma_logc=sqrt(log((sigma_c^2)/(mu_c^2)+1)); %Lognormal std. deviation

%Steel--------------------------------------------------------------------%
fyk=500; Es=200000; epsy=-fy/Es; 
COV_s = 0.04; mu_s = fyk*exp(1.645*COV_s); sigma_s=mu_s*COV_s;
mu_logs=log((mu_s^2)*sqrt(1/(sigma_s^2+mu_s^2))); %Lognormal mean
sigma_logs=sqrt(log((sigma_s^2)/(mu_s^2)+1)); %Lognormal std.deviation

%-----ANALYSIS PARAMETERS-------------------------------------------------%
Force = 246.7e3; %Force in [N] for which beta is to be calculated
start1=mu_c; start2=mu_s; %Starting point

%-----GEOMETRY------------------------------------------------------------%
L=3800; %mm Length of column 
h=150; %mm y-direction
b=240; %mm z-direction
c=33; %mm Concrete cover
d=h-c; %mm, y-direction eff height
Ac=h*b; %mm^2 Area of concrete
dsteel=14; %mm R14
As=4*pi*dsteel^2/4; %mm^2 Reinforcement area
h_1=h-2*33; %mm dist between reinforcement
e1y=40; %Applied eccentricity

%1----DIFFERENTIAL EQUATION-----------------------------------------------%
etta = Es/Ec; rho = 0.5*As/(b*d);
mu_merket =(etta-1)*0.5*As/(b*d*etta);
 
A = etta*(rho+mu_merket);
A_B = etta*rho+(etta-1)*c*0.5*As/(b*d^2);

alfa = sqrt(A^2+2*A_B)-A;
I_BB = b*(alfa*d)^3/3;
I_S = 0.5*As*(1-alfa)^2*d^2;
I_S_merket = 0.5*As*(alfa*d-c)^2-(Ec/Es)*0.5*As*(alfa*d-c)^2;
EI = Ec*I_BB+Es*(I_S+I_S_merket);

y = e1y*(((1-cos(sqrt(N/EI)*L))*sin(sqrt(N/EI)*(L/2)))/(sin(sqrt(N/EI)*L))+cos(sqrt(N/EI)*(L/2))-1);
M0=abs(N*y);
m0=matlabFunction(M0);
m0=m0(N,50.08);
m0=m0-M;
m0=matlabFunction(m0);
plotte0=ezplot(m0,[0 45e6 0 2200e3]);
hold on

%2-----LIMIT STATE 1 - COMPRESSION FAILURE--------------------------------%
syms es2
alfa_d=d*(epcu3/(-es2+epcu3));
Nc=b*fc*0.8*alfa_d;
Ntop=epcu3*((alfa_d-c)/alfa_d)*Es*As/2;
Nbot=es2*Es*As/2;

N_func1=Nc+Ntop+Nbot==N;
M_func1=Nc*(h/2-0.8*alfa_d/2)+Ntop*h_1/2-Nbot*h_1/2; 
ES2=solve(N_func1,es2);
M1=subs(M_func1,es2,ES2(1));
m1=matlabFunction(M1);
m1=m1(N,50.08);
m1=m1-M;
m1=matlabFunction(m1);
plotte1=ezplot(m1,[0 45e6 0 2200e3]);

limit1=M1-M0;
n1=matlabFunction(limit1);

%2-----LIMIT STATE 2 - TENSION FAILURE------------------------------------%
syms M

N2=-fy*As+(((0.8*epcu3*d/(epcu3-2*epsy))*b*fc-fy*As/2+(epcu3-(-2*epsy+epcu3)*c/d)*Es*As/2)+fy*As)*M/((0.8*epcu3*d/(epcu3-2*epsy)*b*fc)*(h/2-0.4*epcu3*d/(epcu3-2*epsy))+(fy*As/2+(epcu3-(-2*epsy+epcu3)*c/d)*Es*As/2)*h_1/2)==N;
M2=solve(N2,M,'ReturnConditions',true); %Only valid for fc>0
m2=matlabFunction(M2.M);
m2=m2(N,50.08,534);
m2=m2-M;
m2=matlabFunction(m2);
plotte2=ezplot(m2,[0 45e6 0 2200e3]);

limit2=M2.M-M0;
n2=matlabFunction(limit2);

%----FORM LIMIT STATE 1---------------------------------------------------%
syms u1 u2
G1(u1,u2)=subs(n1(Force,fc),fc,exp(u1*sigma_logc+mu_logc));

a1=diff(G1,u1);
a2=diff(G1,u2);
a0=G1-a1*u1-a2*u2;

u1(1)=(log(start1)-mu_logc)/sigma_logc;
u2(1)=(log(start2)-mu_logs)/sigma_logs;
i=1;
conv=1;
while conv>10^-6
mu_g1=double(a0(u1(i),u2(i)));
sigma_g1=sqrt(double(a1(u1(i),u2(i)))^2+double(a2(u1(i),u2(i)))^2);
beta1=mu_g1/sigma_g1;
alfa1_1=double(a1(u1(i),u2(i)))/sigma_g1;
alfa2_1=double(a2(u1(i),u2(i)))/sigma_g1;
alfa_sum1=alfa1_1^2+alfa2_1^2;

u1(i+1)=-alfa1_1*beta1;
u2(i+1)=-alfa2_1*beta1;

conv=sqrt((u1(i+1)-u1(i))^2+(u2(i+1)-u2(i))^2);
A0_1(i,:)=double(a0(u1(i),u2(i)));
A1_1(i,:)=double(a1(u1(i),u2(i)));
A2_1(i,:)=double(a2(u1(i),u2(i)));
i=i+1;
end
U1_1=double(u1)';
U2_1=double(u2)';
X1_1=exp(double(u1)*sigma_logc+mu_logc)';
X2_1=exp(double(u2)*sigma_logs+mu_logs)';

%----FORM LIMIT STATE 2---------------------------------------------------%
syms u1 u2 clear
G2(u1,u2)=subs(n2(Force,fc,fy),[fc fy],[exp(u1*sigma_logc+mu_logc),exp(u2*sigma_logs+mu_logs)]);

a1=diff(G2,u1);
a2=diff(G2,u2);
a0=G2-a1*u1-a2*u2;

u1(1)=(log(start1)-mu_logc)/sigma_logc;
u2(1)=(log(start2)-mu_logs)/sigma_logs;

i=1;
conv=1;
while conv>10^-6
mu_g2=double(a0(u1(i),u2(i)));
sigma_g2=sqrt(double(a1(u1(i),u2(i)))^2+double(a2(u1(i),u2(i)))^2);
beta2=mu_g2/sigma_g2;
alfa1_2=double(a1(u1(i),u2(i)))/sigma_g2;
alfa2_2=double(a2(u1(i),u2(i)))/sigma_g2;
alfa_sum2=alfa1_2^2+alfa2_2^2;

u1(i+1)=-alfa1_2*beta2;
u2(i+1)=-alfa2_2*beta2;
conv=sqrt((u1(i+1)-u1(i))^2+(u2(i+1)-u2(i))^2);

A0_2(i,:)=double(a0(u1(i),u2(i)));
A1_2(i,:)=double(a1(u1(i),u2(i)));
A2_2(i,:)=double(a2(u1(i),u2(i)));
i=i+1;
end

U1_2=double(u1)';
U2_2=double(u2)';
X1_2=exp(double(u1)*sigma_logc+mu_logc)';
X2_2=exp(double(u2)*sigma_logs+mu_logs)';

%PLOT TOOLS
%{
%----PLOT REAL SPACE------------------------------------------------------%
%Limit state 1------------------------------------------------------------%
figure(1)
hold on
plot_1=plot([X1_1(end),X1_1(end)],[300 900],'b-');%Limit state 1

%Limit state 2------------------------------------------------------------%
nplot2=matlabFunction(n2(Force,fc,fy));
plot_2=ezplot(nplot2,[0,80,300,900]);
plot_2.Color='red'; plot_2.LineStyle='-';

%Form limit state 1-------------------------------------------------------%
syms X1 X2
G_x1=A0_1+A1_1*((log(X1)-mu_logc)/sigma_logc)+A2_1*((log(X2)-mu_logs)/sigma_logs)==0;
sol1_x1=solve(G_x1(length(A0_1)),X1,'returnconditions',true);
plot_3=plot([double(sol1_x1.X1),double(sol1_x1.X1)],[300 900],'b--');

%Form limit state 2-------------------------------------------------------%
syms X1 X2 clear
G_x2=A0_2+A1_2*((log(X1)-mu_logc)/sigma_logc)+A2_2*((log(X2)-mu_logs)/sigma_logs);
g_x2=matlabFunction(G_x2(length(A0_2)));
plot_4=ezplot(g_x2,[0,80,300,900]);
plot_4.Color='red'; plot_4.LineStyle='--';

%Design points------------------------------------------------------------%
plot_5=plot(X1_1(end),X2_1(end),'kx');
plot_6=plot(X1_2(end),X2_2(end),'kx');

%Joint probability--------------------------------------------------------%
fx1=1/(X1*sqrt(2*pi*sigma_logc^2))*exp(-(log(X1)-mu_logc)^2/(2*sigma_logc^2));
fx2=1/(X2*sqrt(2*pi*sigma_logs^2))*exp(-(log(X2)-mu_logs)^2/(2*sigma_logs^2));
fx1x2=fx1*fx2;
plot_7=fcontour(fx1x2,[0 80 300 900],'-','linecolor',[0.8,0.8,0.8],'levellist',[1e-4 1e-5 1e-10 1e-20],'MeshDensity',200);

%Axes loacated at the starting design point-------------------------------%
plot_8=plot([start1,start1],[0 1000],'color',[0.8,0.8,0.8]);
plot_9=plot([0 100],[start2,start2],'color',[0.8,0.8,0.8]);


axis([0 80 300 900])
axis square
xlabel('f_c [MPa]')
ylabel('f_y [MPa]')
title('')
%----PLOT STANDARD NORMAL SPACE-------------------------------------------%
%Limit state 1------------------------------------------------------------%
syms u1 u2 clear
figure(2)
hold on
plotu1=plot([U1_1(end),U1_1(end)],[-10 10],'b-');%Limit state 1

%Limit state 2------------------------------------------------------------%
nuplot2=matlabFunction(G2);
plotu_2=ezplot(nuplot2,[-10,10,-10,10]);
plotu_2.Color='red';

%Form limit state 1-------------------------------------------------------%
syms U1 U2
G_u1=A0_1+A1_1*U1+A2_1*U2==0;
sol1_u1=solve(G_u1(length(A0_1)),U1);
plotu_3=plot([double(sol1_u1),double(sol1_u1)],[-10 10],'b--');

%Form limit state 2-------------------------------------------------------%
syms U1 U2 clear
G_u2=A0_2+A1_2*U1+A2_2*U2;
g_u2=matlabFunction(G_u2(end));
plotu_4=ezplot(g_u2,[-10,10,-10,10]);
plotu_4.Color='red'; plotu_4.LineStyle='--';

%Design points------------------------------------------------------------%
plotu_5=plot(U1_1(end),U2_1(end),'kx');
plotu_6=plot(U1_2(end),U2_2(end),'kx');

%Joint probability--------------------------------------------------------%
fu1=1/sqrt(2*pi)*exp(-(U1^2)/2);
fu2=1/sqrt(2*pi)*exp(-(U2^2)/2);
fu1u2=fu1*fu2;
plotu_7=fcontour(fu1u2,[-10 10 -10 10],'-','linecolor',[0.8,0.8,0.8],'levellist',[0.05 0.01 1e-4 1e-10 1e-20],'MeshDensity',200);

%Axes loacated at the starting design point-------------------------------%
plotu_8=plot([0,0],[-10 10],'color',[0.8,0.8,0.8]);
plotu_9=plot([-10 10],[0,0],'color',[0.8,0.8,0.8]);

axis([-10 10 -10 10])
axis square
xlabel('f_c in N(0,1)')
ylabel('f_y in N(0,1)')
title('')
%} 
%----SYSTEM RELIABILITY---------------------------------------------------%
beta=[beta1;beta2];
alfa=[alfa1_1 alfa1_2; alfa2_1 alfa2_2];

[Pf,rho]=system_probability(beta,alfa);
