clear all
tic
syms fc fy N positive
%-------Material parameters------------%
% Concrete
fck=45; epcu3=0.0035; Ec= 22*(fc/10)^0.3*1000;
COV_1 = 0.15; mu_1 = (fck/1.15)*exp(1.645*COV_1); sigma_1=mu_1*COV_1;
mu_logc=log((mu_1^2)*sqrt(1/(sigma_1^2+mu_1^2)));
sigma_logc=sqrt(log((sigma_1^2)/(mu_1^2)+1));

% Steel
fyk=500; Es=200000; epsy=-fy/Es; 
COV_2 = 0.04; mu_2 = fyk*exp(1.645*COV_2); sigma_s=mu_2*COV_2;
mu_logs=log((mu_2^2)*sqrt(1/(sigma_s^2+mu_2^2)));
sigma_logs=sqrt(log((sigma_s^2)/(mu_2^2)+1));
%---------------------------------------%
%---------GEOMETRY----------------------%
L=3800; %mm Length of column 
h=150; %mm y-direction
b=240; %mm z-direction
c=33; %mm
d=h-c; %mm, y-direction eff height
Ac=h*b; %mm^2 Area of concrete
dsteel=14; %mm R14
As=4*pi*dsteel^2/4; %mm^2 Reinforcement area
h_1=h-2*33; %mm dist between reinforcement
e1y=40; %Applied eccentricity
%---------------------------------------%
% ANALYSIS
Force = 245e3;
start1=mu_1; start2=mu_2; %Starting points


%---------------------------------------------------------------------%

%1----DIFFERENTIAL EQUATION-----------------------------------------------%
etta = Es/Ec; rho = 0.5*As/(b*d);
mu_merket =(etta-1)*0.5*As/(b*d*etta);
 
A = etta*(rho+mu_merket);
A_B = etta*rho+(etta-1)*c*0.5*As/(b*d^2);

alfa = sqrt(A^2+2*A_B)-A;
I_BB = b*(alfa*d)^3/3;
I_S = 0.5*As*(1-alfa)^2*d^2;
I_S_merket = 0.5*As*(alfa*d-c)^2-(Ec/Es)*0.5*As*(alfa*d-c)^2;
EI = Ec*I_BB+Es*(I_S+I_S_merket);

y = e1y*(((1-cos(sqrt(N/EI)*L))*sin(sqrt(N/EI)*(L/2)))/(sin(sqrt(N/EI)*L))+cos(sqrt(N/EI)*(L/2))-1);
M0=abs(N*y);

%2-----LIMIT STATE 1 - COMPRESSION FAILURE--------------------------------%
syms es2
alfa_d=d*(epcu3/(-es2+epcu3));
Nc=b*fc*0.8*alfa_d;
Ntop=epcu3*((alfa_d-c)/alfa_d)*Es*As/2;
Nbot=es2*Es*As/2;

N_func1=Nc+Ntop+Nbot==N;
M_func1=Nc*(h/2-0.8*alfa_d/2)+Ntop*h_1/2-Nbot*h_1/2; 
ES2=solve(N_func1,es2);
M1=subs(M_func1,es2,ES2(1));

limit1=M1-M0;
n1=matlabFunction(limit1);

%2-----LIMIT STATE 2 - TENSION FAILURE------------------------------------%
syms M

N2=-fy*As+(((0.8*epcu3*d/(epcu3-2*epsy))*b*fc-fy*As/2+(epcu3-(-2*epsy+epcu3)*c/d)*Es*As/2)+fy*As)*M/((0.8*epcu3*d/(epcu3-2*epsy)*b*fc)*(h/2-0.4*epcu3*d/(epcu3-2*epsy))+(fy*As/2+(epcu3-(-2*epsy+epcu3)*c/d)*Es*As/2)*h_1/2)==N;
M2=solve(N2,M,'ReturnConditions',true); %Only valid for fc>0
limit2=M2.M-M0;
n2=matlabFunction(limit2);

%----FORM/SORM LIMIT STATE 1---------------------------------------------------%
% Transforming to standard space
syms U1 U2
G1(U1,U2)=subs(n1(Force,fc),fc,exp(U1*sigma_logc+mu_logc));

a1=diff(G1,U1);
a2=diff(G1,U2);
a0=G1-a1*U1-a2*U2;
b1_sorm=0.5*diff(a1,U1);
b2_sorm=0.5*diff(a2,U2);
a0_sorm=G1-a1*U1-a2*U2 + b1_sorm*U1^2 + b2_sorm*U2^2;

u1(1)=(log(start1)-mu_logc)/sigma_logc;
u2(1)=(log(start2)-mu_logs)/sigma_logs;

% Gradient and Hessian
gradi=[a1;a2];
hessian = ([diff(a1,U1) diff(a1,U2); diff(a2,U1) diff(a2,U2)]);
I=eye(2,2);

i=1;
conv=1;
while conv>10^-4
mu_g1=double(a0(u1(i),u2(i)));
sigma_g1=sqrt(double(a1(u1(i),u2(i)))^2+double(a2(u1(i),u2(i)))^2);
beta1=mu_g1/sigma_g1;
alfa1_1=double(a1(u1(i),u2(i)))/sigma_g1;
alfa2_1=double(a2(u1(i),u2(i)))/sigma_g1;
alfa_sum1=alfa1_1^2+alfa2_1^2;

u1(i+1)=-alfa1_1*beta1;
u2(i+1)=-alfa2_1*beta1;

% SORM PROBABILITY OF FAILURE
gradi_star=gradi(u1(i+1),u2(i+1));
gradi_length=double(sqrt(sum(gradi_star.^2))); 
% P & H_tilde
P=gradi_length^-2*double(gradi_star)*double(transpose(gradi_star));
H_tilde=I + (beta1)*gradi_length^-1*double(hessian(u1(i+1),u2(i+1)));

% SORM factor & Pr(F)
SORM_factor1 = (det(((I-P)*H_tilde*(I-P))+P))^(-0.5); 
pf_0 = normcdf(-beta1,0,1); 
Pf1(i+1)=SORM_factor1*pf_0; 

conv=sqrt((u1(i+1)-u1(i))^2+(u2(i+1)-u2(i))^2);
%{
A0_1(i,:)=double(a0(u1(i),u2(i)));
A1_1(i,:)=double(a1(u1(i),u2(i)));
A2_1(i,:)=double(a2(u1(i),u2(i)));
A0_sorm_1(i,:)=double(a0_sorm(u1(i),u2(i)));
B1_sorm_1(i,:)=double(b1_sorm(u1(i),u2(i)));
B2_sorm_1(i,:)=double(b2_sorm(u1(i),u2(i)));
%}
i=i+1;
toc
end
U1_1=double(u1)';
U2_1=double(u2)';
X1_1=exp(double(u1)*sigma_logc+mu_logc)';
X2_1=exp(double(u2)*sigma_logs+mu_logs)';

A0_sorm_1=double(a0_sorm(u1(end),u2(end)));
A1_sorm_1=double(a1(u1(end),u2(end)));
A2_sorm_1=double(a2(u1(end),u2(end)));
B1_sorm_1=double(b1_sorm(u1(i),u2(i)));
B2_sorm_1=double(b2_sorm(u1(i),u2(i)));

disp('Limit state 1 done');
toc
%----FORM/SORM LIMIT STATE 2---------------------------------------------------%
syms U1 U2 clear
u1=0; u2=0;
% Transforming to standard space
G2(U1,U2)=subs(n2(Force,fc,fy),[fc fy],[exp(U1*sigma_logc+mu_logc),exp(U2*sigma_logs+mu_logs)]);

a1=diff(G2,U1);
a2=diff(G2,U2);
a0=G2-a1*U1-a2*U2;
b1_sorm=0.5*diff(a1,U1);
b2_sorm=0.5*diff(a2,U2);
a0_sorm=G2-a1*U1-a2*U2 + b1_sorm*U1^2 + b2_sorm*U2^2;

u1(1)=(log(start1)-mu_logc)/sigma_logc;
u2(1)=(log(start2)-mu_logs)/sigma_logs;

% Gradient and hessian
gradi=[a1;a2];
hessian = ([diff(a1,U1) diff(a1,U2); diff(a2,U1) diff(a2,U2)]);
I=eye(2,2);

i=1;
conv=1;
while conv>10^-4
mu_g2=double(a0(u1(i),u2(i)));
sigma_g2=sqrt(double(a1(u1(i),u2(i)))^2+double(a2(u1(i),u2(i)))^2);
beta2=mu_g2/sigma_g2;
alfa1_2=double(a1(u1(i),u2(i)))/sigma_g2;
alfa2_2=double(a2(u1(i),u2(i)))/sigma_g2;
alfa_sum2=alfa1_2^2+alfa2_2^2;

u1(i+1)=-alfa1_2*beta2;
u2(i+1)=-alfa2_2*beta2;

% SORM PROBABILITY OF FAILURE
gradi_star = gradi(u1(i+1),u2(i+1));
gradi_length=double(sqrt(sum(gradi_star.^2))); 

% I, P & H_tilde
P=gradi_length^-2*double(gradi_star)*double(transpose(gradi_star));
H_tilde=I + (beta2)*gradi_length^-1*double(hessian(u1(i+1),u2(i+1)));

% SORM factor & Pr(F)
SORM_factor2 = (det(((I-P)*H_tilde*(I-P))+P))^(-0.5); 
pf_0 = normcdf(-beta2,0,1); 
Pf2(i+1)=SORM_factor2*pf_0; 

% Convergence criterion
conv=sqrt((u1(i+1)-u1(i))^2+(u2(i+1)-u2(i))^2);

i=i+1;
toc
end
%----Design points-----%
U1_2=double(u1)';
U2_2=double(u2)';
X1_2=exp(double(u1)*sigma_logc+mu_logc)';
X2_2=exp(double(u2)*sigma_logs+mu_logs)';
%----------------------%
A0_sorm_2=double(a0_sorm(u1(end),u2(end)));
A1_sorm_2=double(a1(u1(end),u2(end)));
A2_sorm_2=double(a2(u1(end),u2(end)));
B1_sorm_2=double(b1_sorm(u1(i),u2(i)));
B2_sorm_2=double(b2_sorm(u1(i),u2(i)));

disp('Limit state 2 done')
toc






