clear all
close all
clc

syms fc fy N yE  positive
syms ye

%-----GEOMETRY------------------------------------------------------------%
L=3800; %mm Length of column 
h=150; %mm y-direction
b=240; %mm z-direction
c=33; %mm
d=h-c; %mm, y-direction eff height
Ac=h*b; %mm^2 Area of concrete
dsteel=14; %mm R14
As=4*pi*dsteel^2/4; %mm^2 Reinforcement area
h_1=h-2*33; %mm dist between reinforcement

%-------MATERIAL AND LOAD-------------------------------------------------%
%Concrete-----------------------------------------------------------------%
fck=45; epcu3=0.0026;
%Concrete strength - Lognormal distribution
COV_c = 0.15; mu_c = (fck/1.15)*exp(1.645*COV_c); sigma_c=mu_c*COV_c;
mu_logc=log((mu_c^2)*sqrt(1/(sigma_c^2+mu_c^2)));
sigma_logc=sqrt(log((sigma_c^2)/(mu_c^2)+1));
%Concrete stiffness - Lognormal distribution
COV_E=0.1582; mu_E=35671.55; sigma_E=mu_E*COV_E;
mu_logE=log((mu_E^2)*sqrt(1/(sigma_E^2+mu_E^2)));
sigma_logE=sqrt(log((sigma_E^2)/(mu_E^2)+1));
%Steel--------------------------------------------------------------------%
% Lognormal distribution
fyk=500; Es=200000; epsy=-fy/Es; 
COV_s = 0.04; mu_s = fyk*exp(1.645*COV_s); sigma_s=mu_s*COV_s;
mu_logs=log((mu_s^2)*sqrt(1/(sigma_s^2+mu_s^2)));
sigma_logs=sqrt(log((sigma_s^2)/(mu_s^2)+1));

%Eccentricity-------------------------------------------------------------%
% Normal distribution
COV_e=0.13435; mu_e=40; sigma_e=mu_e*COV_e;


%Load---------------------------------------------------------------------%
% Normal distribution
COV_N=0.2; mu_N=136e3; sigma_N=mu_N*COV_N; 

%-----ANALYSIS PARAMETERS-------------------------------------------------%
%Force = 215e3; %Force in [N] for which beta is to be calculated
start1=mu_c; start2=mu_s; start3=mu_E; start4=mu_e; start5=mu_N;%Starting point

%1----DIFFERENTIAL EQUATION-----------------------------------------------%
etta = Es/yE; rho = 0.5*As/(b*d);
mu_merket =(etta-1)*0.5*As/(b*d*etta);
 
A = etta*(rho+mu_merket);
A_B = etta*rho+(etta-1)*c*0.5*As/(b*d^2);

alfa = sqrt(A^2+2*A_B)-A;
I_BB = b*(alfa*d)^3/3;
I_S = 0.5*As*(1-alfa)^2*d^2;
I_S_merket = 0.5*As*(alfa*d-c)^2-(yE/Es)*0.5*As*(alfa*d-c)^2;
EI = yE*I_BB+Es*(I_S+I_S_merket);

y = ye*(((1-cos(sqrt(N/EI)*L))*sin(sqrt(N/EI)*(L/2)))/(sin(sqrt(N/EI)*L))+cos(sqrt(N/EI)*(L/2))-1);
M0=abs(N*y);

%2-----LIMIT STATE 1 - COMPRESSION FAILURE--------------------------------%
syms es2
alfa_d=d*(epcu3/(-es2+epcu3));
Nc=b*fc*0.8*alfa_d;
Ntop=epcu3*((alfa_d-c)/alfa_d)*Es*As/2;
Nbot=es2*Es*As/2;

N_func1=Nc+Ntop+Nbot==N;
M_func1=Nc*(h/2-0.8*alfa_d/2)+Ntop*h_1/2-Nbot*h_1/2; 
ES2=solve(N_func1,es2);
M1=subs(M_func1,es2,ES2(1));

limit1=M1-M0;
n1=matlabFunction(limit1);

%2-----LIMIT STATE 2 - TENSION FAILURE------------------------------------%
syms M
N2=-fy*As+(((0.8*epcu3*d/(epcu3-2*epsy))*b*fc-fy*As/2+(epcu3-(-2*epsy+epcu3)*c/d)*Es*As/2)+fy*As)*M/((0.8*epcu3*d/(epcu3-2*epsy)*b*fc)*(h/2-0.4*epcu3*d/(epcu3-2*epsy))+(fy*As/2+(epcu3-(-2*epsy+epcu3)*c/d)*Es*As/2)*h_1/2)==N;
M2=solve(N2,M,'ReturnConditions',true); %Only valid for fc>0
limit2=M2.M-M0;
n2=matlabFunction(limit2);

%----CORRELATION----------------------------------------------------------%


%----FORM LIMIT STATE 1---------------------------------------------------%
syms u1 u2 u3 u4 u5
G1(u1,u2,u3,u4,u5)=subs(n1(N,fc,yE,ye),[N,fc,yE,ye],[u5*sigma_N+mu_N,exp(u1*sigma_logc+mu_logc),exp(u3*sigma_logE+mu_logE),u4*sigma_e+mu_e]);

a1=diff(G1,u1);
a2=diff(G1,u2);
a3=diff(G1,u3);
a4=diff(G1,u4);
a5=diff(G1,u5);
b1=0.5*diff(a1,u1);
b2=0.5*diff(a2,u2);
b3=0.5*diff(a3,u3);
b4=0.5*diff(a4,u4);
b5=0.5*diff(a5,u5);
a0=G1-a1*u1-a2*u2-a3*u3-a4*u4-a5*u5;
a0_sorm=G1-a1*u1-a2*u2-a3*u3-a4*u4-a5*u5+b1*u1^2+b2*u2^2+b3*u3^2+b4*u4^2+b5*u5^2;

gradi=[a1;a2;a3;a4;a5];
hessian =([diff(a1,u1) diff(a1,u2) diff(a1,u2) diff(a1,u4) diff(a1,u5); diff(a2,u1) diff(a2,u2) diff(a2,u2) diff(a2,u4) diff(a2,u5);diff(a3,u1) diff(a3,u2) diff(a3,u2) diff(a3,u4) diff(a3,u5);diff(a4,u1) diff(a4,u2) diff(a4,u2) diff(a4,u4) diff(a4,u5);diff(a5,u1) diff(a5,u2) diff(a5,u2) diff(a5,u4) diff(a5,u5)]);
I=eye(5,5);

u1(1)=(log(start1)-mu_logc)/sigma_logc;
u2(1)=(log(start2)-mu_logs)/sigma_logs;
u3(1)=(log(start3)-mu_logE)/sigma_logE;
u4(1)=(start4-mu_e)/sigma_e;
u5(1)=(start5-mu_N)/sigma_N;
i=1;
conv=1;
while conv>10^-6
mu_g1=double(a0(u1(i),u2(i),u3(i),u4(i),u5(i)));
sigma_g1=sqrt(double(a1(u1(i),u2(i),u3(i),u4(i),u5(i)))^2+double(a2(u1(i),u2(i),u3(i),u4(i),u5(i)))^2+double(a3(u1(i),u2(i),u3(i),u4(i),u5(i)))^2+double(a4(u1(i),u2(i),u3(i),u4(i),u5(i)))^2+double(a5(u1(i),u2(i),u3(i),u4(i),u5(i)))^2);
beta1=mu_g1/sigma_g1;
alfa1_1=double(a1(u1(i),u2(i),u3(i),u4(i),u5(i)))/sigma_g1;
alfa2_1=double(a2(u1(i),u2(i),u3(i),u4(i),u5(i)))/sigma_g1;
alfa3_1=double(a3(u1(i),u2(i),u3(i),u4(i),u5(i)))/sigma_g1;
alfa4_1=double(a4(u1(i),u2(i),u3(i),u4(i),u5(i)))/sigma_g1;
alfa5_1=double(a5(u1(i),u2(i),u3(i),u4(i),u5(i)))/sigma_g1;
alfa_sum1=alfa1_1^2+alfa2_1^2+alfa3_1^2+alfa4_1^2+alfa5_1^2;

u1(i+1)=-alfa1_1*beta1;
u2(i+1)=-alfa2_1*beta1;
u3(i+1)=-alfa3_1*beta1;
u4(i+1)=-alfa4_1*beta1;
u5(i+1)=-alfa5_1*beta1;


% SORM PROBABILITY OF FAILURE
gradi_star=gradi(u1(i+1),u2(i+1),u3(i+1),u4(i+1),u5(i+1));
gradi_length=double(sqrt(sum(gradi_star.^2))); 
% P & H_tilde
P=gradi_length^-2*double(gradi_star)*double(transpose(gradi_star));
H_tilde=I + (beta1)*gradi_length^-1*double(hessian(u1(i+1),u2(i+1),u3(i+1),u4(i+1),u5(i+1)));

% SORM factor & Pr(F)
SORM_factor1 = (det(((I-P)*H_tilde*(I-P))+P))^(-0.5); 
pf_01 = normcdf(-beta1,0,1); 
Pf1(i+1)=SORM_factor1*pf_01; 

conv=sqrt((u1(i+1)-u1(i))^2+(u2(i+1)-u2(i))^2+(u3(i+1)-u3(i))^2+(u4(i+1)-u4(i))^2+(u5(i+1)-u5(i))^2);
A0_1(i,:)=double(a0(u1(i),u2(i),u3(i),u4(i),u5(i)));
A1_1(i,:)=double(a1(u1(i),u2(i),u3(i),u4(i),u5(i)));
A2_1(i,:)=double(a2(u1(i),u2(i),u3(i),u4(i),u5(i)));
A3_1(i,:)=double(a3(u1(i),u2(i),u3(i),u4(i),u5(i)));
A4_1(i,:)=double(a4(u1(i),u2(i),u3(i),u4(i),u5(i)));
A5_1(i,:)=double(a5(u1(i),u2(i),u3(i),u4(i),u5(i)));
B1_1(i,:)=double(b1(u1(i),u2(i),u3(i),u4(i),u5(i)));
B2_1(i,:)=double(b2(u1(i),u2(i),u3(i),u4(i),u5(i)));
B3_1(i,:)=double(b3(u1(i),u2(i),u3(i),u4(i),u5(i)));
B4_1(i,:)=double(b4(u1(i),u2(i),u3(i),u4(i),u5(i)));
B5_1(i,:)=double(b5(u1(i),u2(i),u3(i),u4(i),u5(i)));
A0_SORM1(i,:)=double(a0_sorm(u1(i),u2(i),u3(i),u4(i),u5(i)));
i=i+1;
end
U1_1=double(u1)';
U2_1=double(u2)';
U3_1=double(u3)';
U4_1=double(u4)';
U5_1=double(u5)';
X1_1=exp(double(u1)*sigma_logc+mu_logc)';
X2_1=exp(double(u2)*sigma_logs+mu_logs)';
X3_1=exp(double(u3)*sigma_logE+mu_logE)';
X4_1=(double(u4)*sigma_e+mu_e)';
X5_1=(double(u5)*sigma_N+mu_N)';

%----FORM LIMIT STATE 2---------------------------------------------------%
syms u1 u2 u3 u4 u5 clear
G2(u1,u2,u3,u4,u5)=subs(n2(N,fc,fy,yE,ye),[N,fc,fy,yE,ye],[u5*sigma_N+mu_N,exp(u1*sigma_logc+mu_logc),exp(u2*sigma_logs+mu_logs),exp(u3*sigma_logE+mu_logE),u4*sigma_e+mu_e]);

a1=diff(G2,u1);
a2=diff(G2,u2);
a3=diff(G2,u3);
a4=diff(G2,u4);
a5=diff(G2,u5);
b1=0.5*diff(a1,u1);
b2=0.5*diff(a2,u2);
b3=0.5*diff(a3,u3);
b4=0.5*diff(a4,u4);
b5=0.5*diff(a5,u5);
a0=G2-a1*u1-a2*u2-a3*u3-a4*u4-a5*u5;
a0_sorm=G2-a1*u1-a2*u2-a3*u3-a4*u4-a5*u5+b1*u1^2+b2*u2^2+b3*u3^2+b4*u4^2+b5*u5^2;

gradi=[a1;a2;a3;a4;a5];
hessian =([diff(a1,u1) diff(a1,u2) diff(a1,u2) diff(a1,u4) diff(a1,u5); diff(a2,u1) diff(a2,u2) diff(a2,u2) diff(a2,u4) diff(a2,u5);diff(a3,u1) diff(a3,u2) diff(a3,u2) diff(a3,u4) diff(a3,u5);diff(a4,u1) diff(a4,u2) diff(a4,u2) diff(a4,u4) diff(a4,u5);diff(a5,u1) diff(a5,u2) diff(a5,u2) diff(a5,u4) diff(a5,u5)]);
I=eye(5,5);

u1(1)=(log(start1)-mu_logc)/sigma_logc;
u2(1)=(log(start2)-mu_logs)/sigma_logs;
u3(1)=(log(start3)-mu_logE)/sigma_logE;
u4(1)=(start4-mu_e)/sigma_e;
u5(1)=(start5-mu_N)/sigma_N;
i=1;
conv=1;
while conv>10^-6
mu_g2=double(a0(u1(i),u2(i),u3(i),u4(i),u5(i)));
sigma_g2=sqrt(double(a1(u1(i),u2(i),u3(i),u4(i),u5(i)))^2+double(a2(u1(i),u2(i),u3(i),u4(i),u5(i)))^2+double(a3(u1(i),u2(i),u3(i),u4(i),u5(i)))^2+double(a4(u1(i),u2(i),u3(i),u4(i),u5(i)))^2+double(a5(u1(i),u2(i),u3(i),u4(i),u5(i)))^2);
beta2=mu_g2/sigma_g2;
alfa1_2=double(a1(u1(i),u2(i),u3(i),u4(i),u5(i)))/sigma_g2;
alfa2_2=double(a2(u1(i),u2(i),u3(i),u4(i),u5(i)))/sigma_g2;
alfa3_2=double(a3(u1(i),u2(i),u3(i),u4(i),u5(i)))/sigma_g2;
alfa4_2=double(a4(u1(i),u2(i),u3(i),u4(i),u5(i)))/sigma_g2;
alfa5_2=double(a5(u1(i),u2(i),u3(i),u4(i),u5(i)))/sigma_g2;
alfa_sum=alfa1_2^2+alfa2_2^2+alfa3_2^2+alfa4_2^2+alfa5_2^2;

u1(i+1)=-alfa1_2*beta2;
u2(i+1)=-alfa2_2*beta2;
u3(i+1)=-alfa3_2*beta2;
u4(i+1)=-alfa4_2*beta2;
u5(i+1)=-alfa5_2*beta2;


% SORM PROBABILITY OF FAILURE
gradi_star=gradi(u1(i+1),u2(i+1),u3(i+1),u4(i+1),u5(i+1));
gradi_length=double(sqrt(sum(gradi_star.^2))); 
% P & H_tilde
P=gradi_length^-2*double(gradi_star)*double(transpose(gradi_star));
H_tilde=I + (beta2)*gradi_length^-1*double(hessian(u1(i+1),u2(i+1),u3(i+1),u4(i+1),u5(i+1)));

% SORM factor & Pr(F)
SORM_factor2 = (det(((I-P)*H_tilde*(I-P))+P))^(-0.5); 
pf_02 = normcdf(-beta2,0,1); 
Pf2(i+1)=SORM_factor2*pf_02; 

conv=sqrt((u1(i+1)-u1(i))^2+(u2(i+1)-u2(i))^2+(u3(i+1)-u3(i))^2+(u4(i+1)-u4(i))^2+(u5(i+1)-u5(i))^2);A0_2(i,:)=double(a0(u1(i),u2(i),u3(i),u4(i),u5(i)));
A0_2(i,:)=double(a0(u1(i),u2(i),u3(i),u4(i),u5(i)));
A1_2(i,:)=double(a1(u1(i),u2(i),u3(i),u4(i),u5(i)));
A2_2(i,:)=double(a2(u1(i),u2(i),u3(i),u4(i),u5(i)));
A3_2(i,:)=double(a3(u1(i),u2(i),u3(i),u4(i),u5(i)));
A4_2(i,:)=double(a4(u1(i),u2(i),u3(i),u4(i),u5(i)));
A5_2(i,:)=double(a5(u1(i),u2(i),u3(i),u4(i),u5(i)));
B1_2(i,:)=double(b1(u1(i),u2(i),u3(i),u4(i),u5(i)));
B2_2(i,:)=double(b2(u1(i),u2(i),u3(i),u4(i),u5(i)));
B3_2(i,:)=double(b3(u1(i),u2(i),u3(i),u4(i),u5(i)));
B4_2(i,:)=double(b4(u1(i),u2(i),u3(i),u4(i),u5(i)));
B5_2(i,:)=double(b5(u1(i),u2(i),u3(i),u4(i),u5(i)));
A0_SORM2(i,:)=double(a0_sorm(u1(i),u2(i),u3(i),u4(i),u5(i)));
i=i+1;
end
U1_2=double(u1)';
U2_2=double(u2)';
U3_2=double(u3)';
U4_2=double(u4)';
U5_2=double(u5)';
X1_2=exp(double(u1)*sigma_logc+mu_logc)';
X2_2=exp(double(u2)*sigma_logs+mu_logs)';
X3_2=exp(double(u3)*sigma_logE+mu_logE)';
X4_2=(double(u4)*sigma_e+mu_e)';
X5_2=(double(u5)*sigma_N+mu_N)';


%----SYSTEM RELIABILITY---------------------------------------------------%
beta=[beta1;beta2];
beta_SORM=[-norminv(Pf1(end));-norminv(Pf2(end))];
alfa=[alfa1_1 alfa1_2; alfa2_1 alfa2_2;alfa3_1 alfa3_2; alfa4_1 alfa4_2; alfa5_1 alfa5_2];

[Pf,rho]=system_probability(beta,alfa);
[Pf_SORM,rho_SORM]=system_probability(beta_SORM,alfa);

BETA=-norminv(Pf,0,1);
BETA_SORM=-norminv(Pf_SORM,0,1);