%%%%%%%%%%Monte Carlo simulations%%%%%%%%%%%%%%%%
warning('off','all')
clc
clear all
tic
%%%%%%%%%%INPUT PARAMETERS%%%%%%%%%%%%%%%%%%%%%%%
fck = 45; %Characteristic compressive strength from EC2-1-1
fyk=500; %Characteristic yield strength
COV_c = 0.15; %Coefficient of variation concrete
COV_s = 0.04; %Coeffiecent of variation steel yield strength
mean_fc = (fck/1.15)*exp(1.645*COV_c);%Lognormal mean
mean_fy = fyk*exp(1.645*COV_s);%Lognormal mean
number_of_simulations = 100; %Number of Monte Carlo simulations
F = 245; %Force in [kN] for which beta is calculated

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
MC = zeros(number_of_simulations,3);
std_c = COV_c*mean_fc; %Std. deviation of fc
std_y = COV_s*mean_fy; %Std. deviation of fy
logmean_fc = log(mean_fc^2*sqrt(1/(std_c^2+mean_fc^2))) ; %Lognormal mean of concrete compressive strength
logmean_fy = log(mean_fy^2*sqrt(1/(std_y^2+mean_fy^2))) ;%Lognormal mean of steel yield strength
logstd_fc = sqrt(log(COV_c^2+1)); %Lognormal standard deviation of concrete
logstd_fy = sqrt(log(COV_s^2+1)); %Lognormal standard deviation steel

%--------------Generating vectors of random realizations-----------------%
fc = exp(randn(1,number_of_simulations)*logstd_fc+logmean_fc);
fy = exp(randn(1,number_of_simulations)*logstd_fy+logmean_fy);
%------------------------------------------------------------------------%
count = 0;
L = number_of_simulations/20;
Z = 1:1:20;
LU = Z.*L;
j=1;
fprintf('Running simulations....\n')
for i = 1:number_of_simulations
    %--Calculating column capacity by the use of MN-diagram and
    %differential equation-------------------------------------------%
    [MC(i,1),MC(i,2),MC(i,3)] = MNdiagram(fc(i),fy(i),fck);
    %----------------------------------------------------------------%
    if MC(i,1) <= F %Check if failure
        count=count+1;
    end
    if i >= LU(j) %Output progress to command window
        fprintf('More than %6.2f simulations completed....\n',LU(j))
        j=j+1;
    end
end
warning('on','all')
probability_of_failure = count/number_of_simulations; %MC probability of failure
COV_pf = 1/sqrt(number_of_simulations*probability_of_failure); %Coefficient of variation of MC probability of failure
fprintf('Probability of failure is: %6.5f*10^-6\n',probability_of_failure*10^6)
fprintf('Coefficient of variation for failure probability: %6.5f\n',COV_pf)
fprintf('\n')
%fprintf('saving MC-vector...')
%save MC.txt MC -ASCII;
fprintf('Done!')
toc
%Plot tools:
%{
k=0;
for j=1:number_of_simulations
    if MC(j,1)<=F
        k=k+1;
        MC_fail(k,1)=MC(j,2);
        MC_fail(k,2)=MC(j,3);
    end
end

plot1=scatter(MC(:,2),MC(:,3),10,[0.8 0.8 0.8],'filled');
axis([0 80 300 900])
hold on
plot2=scatter(MC_fail(:,1),MC_fail(:,2),10,'k','filled');
legend([plot1,plot2],'Safe','Failure')
axis square
xlabel('f_c [MPa]')
ylabel('f_y [MPa]')
%}