function [NRd_curve,fcm,fym]=MNdiagram(fcm,fym,fck)

%------Geometry----------------------------------------------------------%
L=3800; %mm Length of column 
h=150; %mm y-direction
b=240; %mm z-direction
d=h-33; %mm, y-direction eff height
e1y=40; %mm eccentricity
Ac=h*b; %mm^2 Area of concrete
dsteel=14; %mm R14
As=4*pi*dsteel^2/4; %mm^2 Reinforcement area
c=33; %Concrete cover
h_1=h-2*c; %mm dist between reinforcement

%-----Material------------------------------------------------------------%
[fym,Es,epsy,epsu] = Steel(fym);
[fcm,Ec,epcu3] = Concrete(fck,fcm);

%------Reaction forces----------------------------------------------------%
N_Ed = 0:1000:500e3;%Newton

for j=1:length(fcm)

    %------Differential equation----------------------------------------------%
    etta = Es(j)/Ec(j); rho = 0.5*As/(b*d);
    mu_merket =(etta-1)*0.5*As/(b*d*etta);
 
    A = etta*(rho+mu_merket);
    A_B = etta*rho+(etta-1)*c*0.5*As/(b*d^2);

    alfa = sqrt(A^2+2*A_B)-A;
    I_BB = b*(alfa*d)^3/3;
    I_S = 0.5*As*(1-alfa)^2*d^2;
    I_S_merket = 0.5*As*(alfa*d-c)^2-(Ec(j)/Es(j))*0.5*As*(alfa*d-c)^2;
    EI = Ec(j)*I_BB+Es(j)*(I_S+I_S_merket);%Cross sectional flexural stiffness

    y = e1y*(((1-cos(sqrt(N_Ed./EI)*L)).*sin(sqrt(N_Ed./EI)*(L/2)))./(sin(sqrt(N_Ed./EI)*L))+cos(sqrt(N_Ed./EI)*(L/2))-1);
    M0=abs(N_Ed.*y);%Moment at mid span


    MEd = M0*10^-6;
    NEd = N_Ed*10^-3;
    %-----------MN-diagram ---------------------------------------------------%
    es = -epsu(j):0.001:0.9*epcu3(j); % Strain of bottom reinfocement          
    comprzoneheight = zeros(length(es),1); N_rd = zeros(length(es),1); M_rd = zeros(length(es),1);

    for i = 1:length(es)
        h_virt = epcu3(j)*(h+h_1)/(2*(epcu3(j)-es(i))); %Virtual length points of maximum (positive) and zero strain
        %-----------Calculating strains and stresses---------------------------%
        if 0.8*h_virt >= h
            comprzoneheight(i) = h;
            Nc = b*comprzoneheight(i)*fcm(j); %Normalforce concrete
            es_top = epcu3(j)*(h_virt-h/2+h_1/2)/h_virt; %Strain compression reinforcement
            M_Nc = 0; %Moment concrete
        else 
            comprzoneheight(i) = 0.8*h_virt;
            Nc = b*comprzoneheight(i)*fcm(j); %Normal force concrete
            M_Nc = Nc*(h/2-comprzoneheight(i)/2); %Moment concrete
            es_top = epcu3(j)*(h_virt-h/2+h_1/2)/h_virt; %Strain compr reinforcement
        end
        %----------Stresses in top reinforcement--------------------------%
        if abs(es_top) <= epsy(j)
                    sigma_top = es_top*Es(j);
        elseif es_top <= 0
                    sigma_top = -fym(j);
        else
                    sigma_top = fym(j);
        end
        %-----------------------------------------------------------------%
        %-----------Stresses in bottom reinforcement----------------------%
        if abs(es(i)) <= epsy(j)
                    sigma_bot = es(i)*Es(j);
        elseif es(i) <= 0 
                    sigma_bot = -fym(j);
        else 
                    sigma_bot = fym(j);
        end
        %-----------------------------------------------------------------%
    %---------------------------------------------------------------------%            
    %------------Force equilibrium----------------------------------------%
            Ns_top = sigma_top*As/2;
            Ns_bot = sigma_bot*As/2;
            N_rd(i) = Ns_top + Ns_bot + Nc; %Horisontal likevekt
            M_rd(i) = Ns_top*h_1/2 - Ns_bot*h_1/2+M_Nc; %Momentlikevekt
    %---------------------------------------------------------------------%        
    %---------------------------------------------------------------------%        
    end

%Finding intersections, ie finding capacities:
MRd=10^-6*M_rd; NRd=10^-3*N_rd;
[MRd_curve(j),NRd_curve(j)]=intersections(MRd,NRd,MEd,NEd,0);
end