%--------------------------Monte Carlo simulations------------------------%
%-------------------------------------------------------------------------%
warning('off','all')
clc
clear all
tic
number_of_simulations = 1000; %Number of Monte Carlo simulations
%--------------INPUT PARAMETERS-------------------------------------------%
% Concrete strength
fck=45;
COV_c = 0.15; %Concrete coefficient of variation
mu_c = (fck/1.15)*exp(1.645*COV_c); %Mean in-situ concrete compressive strength
sigma_c=mu_c*COV_c; %Std. deviation concrete
mu_logc=log((mu_c^2)*sqrt(1/(sigma_c^2+mu_c^2))); %Lognormal mean for concrete
sigma_logc=sqrt(log((sigma_c^2)/(mu_c^2)+1)); %Lognormal std. deviation for concrete

% Reinforcement yield strength
fyk=500; %Characteristic yield strength
COV_s = 0.04; %Steel coefficient of variation
mu_s = fyk*exp(1.645*COV_s); %Mean in-situ steel yield strength
sigma_s=mu_s*COV_s; %Std. deviation of steel yield strength
mu_logs=log((mu_s^2)*sqrt(1/(sigma_s^2+mu_s^2))); %Lognormal mean of yield strength
sigma_logs=sqrt(log((sigma_s^2)/(mu_s^2)+1)); %Lognormal std. deviation for yield strength

% Concrete stiffness, Ec
COV_E=0.1582; mu_E=35671.55; sigma_E=mu_E*COV_E;
mu_logE=log((mu_E^2)*sqrt(1/(sigma_E^2+mu_E^2))); %Lognormal mean of Ec
sigma_logE=sqrt(log((sigma_E^2)/(mu_E^2)+1)); %Lognormal std. deviation of Ec

% Eccentricity
COV_e=0.13435; mu_e=40; sigma_e=mu_e*COV_e;

% Load
COV_N=0.2; mu_N=150e3; sigma_N=mu_N*COV_N;

%-------------------------------------------------------------------------%
MC = zeros(number_of_simulations,6);
%------Creating random realizations of material and load parameters-------%
fc = exp(randn(1,number_of_simulations)*sigma_logc+mu_logc);
fy = exp(randn(1,number_of_simulations)*sigma_logs+mu_logs);
Ec = exp(randn(1,number_of_simulations)*sigma_logE+mu_logE);
e1y =randn(1,number_of_simulations)*sigma_e+mu_e;
N =randn(1,number_of_simulations)*sigma_N+mu_N;
%-------------------------------------------------------------------------%
count = 0;
L = number_of_simulations/20;
Z = 1:1:20;
LU = Z.*L;
j=1;
fprintf('Running simulations....\n')
for i = 1:number_of_simulations
    %-----------Finding column resitance based on MN-diagram--------------%
    [MC(i,1),MC(i,2),MC(i,3),MC(i,4),MC(i,5)] = MNdiagram(fc(i),fy(i),Ec(i),e1y(i),fck);
    MC(i,6)=N(i)/10^3;
    %---------------------------------------------------------------------%
    if MC(i,1) <= MC(i,6) %Check if failure
        count=count+1;
    end
    if i >= LU(j) %Output analysis progress to command window
        fprintf('More than %6.2f simulations completed....\n',LU(j))
        j=j+1;
    end
end
warning('on','all')
probability_of_failure = count/number_of_simulations; %Probability of failure, Pf
COV_pf = 1/sqrt(number_of_simulations*probability_of_failure); %Estimated coefficient of variation of Pf
fprintf('Probability of failure is: %6.5f*10^-6\n',probability_of_failure*10^6)
fprintf('Coefficient of variation for failure probability: %6.5f\n',COV_pf)
fprintf('\n')
fprintf('saving MC-vector...')
save MC.txt MC -ASCII;
fprintf('Done!')
toc
%Plot tools:
%{
k=0;
for j=1:number_of_simulations
    if MC(j,1)<=F
        k=k+1;
        MC_fail(k,1)=MC(j,2);
        MC_fail(k,2)=MC(j,3);
    end
end

plot1=scatter(MC(:,2),MC(:,3),10,[0.8 0.8 0.8],'filled');
axis([0 80 300 900])
hold on
plot2=scatter(MC_fail(:,1),MC_fail(:,2),10,'k','filled');
legend([plot1,plot2],'Safe','Failure')
axis square
xlabel('f_c [MPa]')
ylabel('f_y [MPa]')
%}