function [b_vector,a_vector1] = RSM_generation(R,design_point_c,design_point_s,f,sigma_logc,sigma_logs,mu_logc,mu_logs,fck)
%{
%Generates response surface on the resistance side.

%a_vector is on the form a_vector(i,:)=[1 z1 z2 z1^2 z2^2 z1z2],
%where zi are realizations of the stochastic variables.
%R is a vector with resistances 

%design_point_c is a vector of the design points for concrete at the
%various iterations, and is on the form [fcd1 fcd2 ..... fcdn]
%fcd1 is typically chosen equal to fcm

%design_point_s is a vector of the design points for steel at the
%various iterations, and is on the form [fyd1 fyd2 ..... fydn]
%fyd1 is typically chosen equal to fym

%COV_c and COV_s are the coefficients of variation for concrete and steel
%mu_fc is the mean value of concrete strength (typically mean in-situ)
%mu_fy is the mean value of steel strength (typically mean in-situ)

%R is on the form transpose(R)=[R1 R2 R3 R4 R5 R6]
%}
%-----------Calculating b_vector using least squares----------------------%
for i = 1:length(design_point_c)
    [fc, fy] = RSM_sample(design_point_c(i),design_point_s(i),f,sigma_logc,sigma_logs,mu_logc,mu_logs,fck);
    a_vector(:,:,i) = [1 fc(1) fy(1) (fc(1))^2 (fy(1))^2 (fc(1))*(fy(1));
                        1 fc(2) fy(2) (fc(2))^2 (fy(2))^2 (fc(2))*(fy(2));
                        1 fc(3) fy(3) (fc(3))^2 (fy(3))^2 (fc(3))*(fy(3));
                        1 fc(4) fy(4) (fc(4))^2 (fy(4))^2 (fc(4))*(fy(4));
                        1 fc(5) fy(5) (fc(5))^2 (fy(5))^2 (fc(5))*(fy(5));
                        1 fc(6) fy(6) (fc(6))^2 (fy(6))^2 (fc(6))*(fy(6))];
end
a_vector1=a_vector(:,:,1);
if length(design_point_c)==1
    a_vector1= a_vector(:,:,1);    
else
    for j=1:length(design_point_c)-1
        a_vector1=[a_vector1;a_vector(:,:,j+1)];
    end
end
format long
A=a_vector1.'*a_vector1;
B=a_vector1.'*R;
b_vector=A\B;
%-------------------------------------------------------------------------%
end