function [b_vector,a_vector1] = RSM_generation(R,design_point_c,design_point_s,design_point_E,design_point_e,design_point_N,f,sigma_logc,sigma_logs,sigma_logE,sigma_c,sigma_s,sigma_E,sigma_e,sigma_N,fck)
%Generates response surface for on the resistance side.

%R is a vector with resistances.
%material-set: a_vector(i,:), and is an 11 by 11*n matrix, where n is the iteration number. 

%design_point_i is a vector of the design points for parameter "i" at the
%various iterations, and is on the form [fcd1 fcd2 ..... fcdn]

%COV_i are the coefficients of variation for the different parameters
%mu_fc is the mean value of concrete strength (typically mean in-situ)
%mu_fy is the mean value of steel strength (typically mean in-situ)

%R is on the form transpose(R)=[R1 R2 R3 R4 R5 R6 R7 R8 R9 R10 R11 .....]
%-----Calculating b_vector with a least squares approach------------------%
for i = 1:length(design_point_c)
    [fc, fy, Ec, e1y, N] = RSM_sample(design_point_c(i),design_point_s(i),design_point_E(i),design_point_e(i),design_point_N(i),f,sigma_logc,sigma_logs,sigma_logE,sigma_c,sigma_s,sigma_E,sigma_e,sigma_N,fck);
    a_vector(:,:,i) = [1 fc(1) fy(1) Ec(1) e1y(1) N(1) fc(1)^2 fy(1)^2 Ec(1)^2 e1y(1)^2 N(1)^2;
                       1 fc(2) fy(2) Ec(2) e1y(2) N(2) fc(2)^2 fy(2)^2 Ec(2)^2 e1y(2)^2 N(2)^2;
                       1 fc(3) fy(3) Ec(3) e1y(3) N(3) fc(3)^2 fy(3)^2 Ec(3)^2 e1y(3)^2 N(3)^2;
                       1 fc(4) fy(4) Ec(4) e1y(4) N(4) fc(4)^2 fy(4)^2 Ec(4)^2 e1y(4)^2 N(4)^2;
                       1 fc(5) fy(5) Ec(5) e1y(5) N(5) fc(5)^2 fy(5)^2 Ec(5)^2 e1y(5)^2 N(5)^2;
                       1 fc(6) fy(6) Ec(6) e1y(6) N(6) fc(6)^2 fy(6)^2 Ec(6)^2 e1y(6)^2 N(6)^2;
                       1 fc(7) fy(7) Ec(7) e1y(7) N(7) fc(7)^2 fy(7)^2 Ec(7)^2 e1y(7)^2 N(7)^2;
                       1 fc(8) fy(8) Ec(8) e1y(8) N(8) fc(8)^2 fy(8)^2 Ec(8)^2 e1y(8)^2 N(8)^2;
                       1 fc(8) fy(9) Ec(9) e1y(9) N(9) fc(9)^2 fy(9)^2 Ec(9)^2 e1y(9)^2 N(9)^2;
                       1 fc(8) fy(10) Ec(10) e1y(10) N(10) fc(10)^2 fy(10)^2 Ec(10)^2 e1y(10)^2 N(10)^2;
                       1 fc(8) fy(11) Ec(11) e1y(11) N(11) fc(11)^2 fy(11)^2 Ec(11)^2 e1y(11)^2 N(11)^2];
end
a_vector1=a_vector(:,:,1);
if length(design_point_c)==1
    a_vector1= a_vector(:,:,1);    
else
    for j=1:length(design_point_c)-1
        a_vector1=[a_vector1;a_vector(:,:,j+1)];
    end
end
format long
A=a_vector1.'*a_vector1;
B=a_vector1.'*R;
b_vector=A\B;
%-------------------------------------------------------------------------%
end