function [design1,design2,beta,alfa1,alfa2,X1,X2,U1,U2,A0,A1,A2,A0_sorm,B1,B2,SORM_factor] = FORM(mu_log1,mu_log2,Force,b_vector,sigma_log1,sigma_log2,start1,start2,correlation_matrix)
syms u1 u2
%--------Transforming to Y-space-----------%
A(u1,u2) = [u1;u2];
T = chol(correlation_matrix,'lower');
B(u1,u2)=T*A;
u1_merket(u1,u2) = T(1,1)*u1+T(1,2)*u2;
u2_merket(u1,u2) = T(2,1)*u1+T(2,2)*u2;

X1 = exp(u1_merket*sigma_log1+mu_log1);
X2 = exp(u2_merket*sigma_log2+mu_log2);
%------------------------------------------%
G = [1 X1 X2 X1^2 X2^2 X1*X2]*b_vector-Force; %Limit state
%----Linearizing limit state-----%
a1(u1,u2)=diff(G,u1);
a2(u1,u2)=diff(G,u2);
a0(u1,u2)=G-a1*u1-a2*u2;
%--------------------------------%
%---SORM parameters--------------------------%
b1=0.5*diff(a1,u1);
b2=0.5*diff(a2,u2);
a0_sorm=G-a1*u1-a2*u2 + b1*u1^2 + b2*u2^2;
% Gradient and Hessian
gradi=[a1;a2];
hessian = ([diff(a1,u1) diff(a1,u2); diff(a2,u1) diff(a2,u2)]);
I=eye(2,2);
%--------------------------------------------%
%---Staring points of iterations-------------%
u1(1)=double((log(start1)-mu_log1)/sigma_log1);
u2(1)=double((log(start2)-mu_log2)/sigma_log2);
x1(1)=double(exp(u1(1)*sigma_log1+mu_log1));
x2(1)=double(exp(u2(1)*sigma_log2+mu_log2));
%--------------------------------------------%
i=1;
conv=1;
while conv>10^-4
mu_g=double(a0(u1(i),u2(i)));
sigma_g=double(sqrt(a1(u1(i),u2(i))^2+a2(u1(i),u2(i))^2));
beta=double(mu_g/sigma_g);
alfa1=double(a1(u1(i),u2(i))/sigma_g);
alfa2=double(a2(u1(i),u2(i))/sigma_g);

alfa_sum=alfa1^2+alfa2^2;

u1(i+1)=-alfa1*beta; %Updated design point
u2(i+1)=-alfa2*beta; %Updated design point

conv1=u1(i+1)-u1(i);
conv2=u2(i+1)-u2(i);
conv=sqrt(conv1^2+conv2^2); %Convergence criterion
A0(i,:)=double(a0(u1(i),u2(i)));
A1(i,:)=double(a1(u1(i),u2(i)));
A2(i,:)=double(a2(u1(i),u2(i)));

A0_sorm(i,:)=double(a0_sorm(u1(i),u2(i)));
B1(i,:)=double(b1(u1(i),u2(i)));
B2(i,:)=double(b2(u1(i),u2(i)));
%---Kill switch if no convergence after 400 iterations---%
if i == 400
    error('FORM did not converge....')
end
%----------------------------------------------------------%
i=i+1;
end
%-----Design points--------%
U1=transpose(double(u1));
U2=transpose(double(u2));
X1=exp(double(T(1,1)*u1+T(1,2)*u2)*sigma_log1+mu_log1)';
X2=exp(double(T(2,1)*u1+T(2,2)*u2)*sigma_log2+mu_log2)';

design1 = X1(end);
design2 = X2(end);
%--------------------------%
%---Finding SORM-factor----%
gradi_star = gradi(u1(end),u2(end));
gradi_length=double(sqrt(sum(gradi_star.^2))); 

% I, P & H_tilde:
P=gradi_length^-2*double(gradi_star)*double(transpose(gradi_star));
H_tilde=I + (beta)*gradi_length^-1*double(hessian(u1(end),u2(end)));

% SORM factor:
SORM_factor = (det(((I-P)*H_tilde*(I-P))+P))^(-0.5); 
%---------------------------%

end