%%%%%%%%%RSM-FORM MAIN SCRIPT%%%%%%%
clc
clear all
%-----------Set material parameters-----------------%
fck=100;
fyk=500;
COV_c = 0.15; %Concrete coefficient of variation
COV_s = 0.04; %Steel coefficient of variation
mu_c = (fck/1.15)*exp(1.645*COV_c); %Mean in-situ concrete compressive strength
mu_s = fyk*exp(1.645*COV_s); %Mean in-situ steel yield strength
sigma_c=mu_c*COV_c;
sigma_s=mu_s*COV_s;
Force = 208000; %Force in [N] for which beta is to be calculated

correlation_matrix = [1 0;0 1]; %Correlation matrix
%---------------------------------------------------%
%-----Lognormal mean and standard deviation---------%
mu_logc=log((mu_c^2)*sqrt(1/(sigma_c^2+mu_c^2)));
mu_logs=log((mu_s^2)*sqrt(1/(sigma_s^2+mu_s^2)));
sigma_logc=sqrt(log((sigma_c^2)/(mu_c^2)+1));
sigma_logs=sqrt(log((sigma_s^2)/(mu_s^2)+1));
%---------------------------------------------------%
%---------Set starting point for RSM sampling,and f (sample scatter)------%
design_point_c = [40];
design_point_s = [400];
f = 3.0;
%-------------------------------------------------------------------------%

%-----Set convergence norms for RSM and FORM iterations------%
e_RSM = 0.01; %Convergence norm e_RSM = sqrt((beta(i)-beta(i-1))^2)
e_FORM = 10^-4; % Covergence norm e_FORM = sqrt((xda(j)-xda(j-1))^2+(xdb(j)-xdb(j-1))^2)
%------------------------------------------------------------%
i=0;  %Iteration number
R=[]; %Resistance vector (increases for every RSM-iteration)
b_vector_2 = []; %Vector containing the coefficients from least squares calculation from previous RSM-iteraions
beta=[];
alfa1=[];
alfa2=[];
x1={}; x2={}; u1={}; u2={};
CONV=1;

while CONV >= e_RSM %Check for convergence
        i=i+1; %Update iteration number
        
        %1) USE RSM_materials with design_point_c and design_point_s as
        %   input to write the materials to .DAT-file (DIANA)
       
        [fc, fy, Ec, Es, fct, Gc, Gf, kfy, ey, eu] = RSM_sampling(design_point_c(i),design_point_s(i),f,sigma_logc,sigma_logs,mu_logc,mu_logs,fck,COV_c);
        
        %2) Run analyses in DIANA via batch, and extract resistances
        
        %-------------Running batch file-----------------------%
        %Specify path to .BAT-file after the exclamation mark
        !PATH_TO_BATCH-file
        %------------------------------------------------------%
        
        %3) Append new resistances to the R-vector
        [Ri]=Find_capacity();
        R=vertcat(R,Ri(:,1));
        
        %4) Generate response surface
        [b_vector_2(:,i),a_vector] = RSM_generation(R,design_point_c,design_point_s,f,COV_c,sigma_logc,sigma_logs,mu_logc,mu_logs,fck);
        
        %5) Run FORM
        [design_point_c(i+1),design_point_s(i+1),beta(i),alfa1(i),alfa2(i),x1{i},x2{i},u1{i},u2{i},A0{i},A1{i},A2{i},A_sorm{i},B1{i},B2{i},SORM_factor(i)] = FORM(mu_logc,mu_logs,Force,b_vector_2(:,i),sigma_logc,sigma_logs,design_point_c(i),design_point_s(i),correlation_matrix);
        pf_0 = normcdf(-beta(i),0,1); %FORM probability of failure
        Pf(i)=SORM_factor(i)*pf_0; %SORM probability of failure
        if i==1
            CONV=1;
        else
            CONV=sqrt((beta(i)-beta(i-1))^2); %Convergence criterion
        end
end    

fprintf('Reliability form-beta: %6.2f \n',beta(i))
fprintf('Design point fcd: %6.2f\n',design_point_c(i+1))
fprintf('Design point fyd: %6.2f\n',design_point_s(i+1))
fprintf('Probability of failure FORM: %6.10f\n',pf_0)
fprintf('Probability of failure SORM: %6.10f\n',Pf(end))
fprintf('Number of RSM-iterations: %6.2f\n',i)