function [design1,design2,design3,design4,beta,alfa1,alfa2,alfa3,alfa4,X1,X2,X3,X4,U1,U2,U3,U4,A0,A1,A2,A3,A4,A0_sorm,B1,B2,B3,B4,SORM_factor] = FORM(mu_log1,mu_log2,mu_log3,mu_4,Force,b_vector,sigma_log1,sigma_log2,sigma_log3,sigma_4,start1,start2,start3,start4,correlation_matrix)
syms u1 u2 u3 u4
%----Transforming to uncorrelated standard normal space------%
A(u1,u2,u3,u4) = [u1;u2;u3;u4];
T = chol(correlation_matrix,'lower');
B(u1,u2,u3,u4)=T*A;
u1_merket(u1,u2,u3,u4) = T(1,1)*u1+T(1,2)*u2+T(1,3)*u3+T(1,4)*u4;
u2_merket(u1,u2,u3,u4) = T(2,1)*u1+T(2,2)*u2+T(2,3)*u3+T(2,4)*u4;
u3_merket(u1,u2,u3,u4) = T(3,1)*u1+T(3,2)*u2+T(3,3)*u3+T(3,4)*u4;
u4_merket(u1,u2,u3,u4) = T(4,1)*u1+T(4,2)*u2+T(4,3)*u3+T(4,4)*u4;

X1 = exp(u1_merket*sigma_log1+mu_log1);
X2 = exp(u2_merket*sigma_log2+mu_log2);
X3 = exp(u3_merket*sigma_log3+mu_log3);
X4 = (u4_merket*sigma_4+mu_4);
%------------------------------------------------------------%

G = [1 X1 X2 X3 X4 X1^2 X2^2 X3^2 X4^2]*b_vector-Force; %Limit state
%---Approximating LSF for FORM and SORM-----%
a1=diff(G,u1);
a2=diff(G,u2);
a3=diff(G,u3);
a4=diff(G,u4);
a0=G-a1*u1-a2*u2-a3*u3-a4*u4;

% for SORM
b1=0.5*diff(a1,u1);
b2=0.5*diff(a2,u2);
b3=0.5*diff(a3,u3);
b4=0.5*diff(a4,u4);
a0_sorm=G-a1*u1-a2*u2-a3*u3-a4*u4 + b1*u1^2 + b2*u2^2 + b3*u3^2 + b4*u4^2;
% Gradient and Hessian
gradi=[a1;a2;a3;a4];
hessian = ([diff(a1,u1) diff(a1,u2) diff(a1,u3) diff(a1,u4); diff(a2,u1) diff(a2,u2) diff(a2,u3) diff(a2,u4);diff(a3,u1) diff(a3,u2) diff(a3,u3) diff(a3,u4);diff(a4,u1) diff(a4,u2) diff(a4,u3) diff(a4,u4)]);
I=eye(4,4);
%Starting points of iterations
u1(1)=(log(start1)-mu_log1)/sigma_log1;
u2(1)=(log(start2)-mu_log2)/sigma_log2;
u3(1)=(log(start3)-mu_log3)/sigma_log3;
u4(1)=(start4-mu_4)/sigma_4;
%--------------------------------------------%
i=1;
conv=1;
while conv>10^-4 %Check for convergence
mu_g=double(a0(u1(i),u2(i),u3(i),u4(i)));
sigma_g=double(sqrt(a1(u1(i),u2(i),u3(i),u4(i))^2+a2(u1(i),u2(i),u3(i),u4(i))^2+a3(u1(i),u2(i),u3(i),u4(i))^2+a4(u1(i),u2(i),u3(i),u4(i))^2));
beta(i)=double(mu_g/sigma_g);
alfa1=double(a1(u1(i),u2(i),u3(i),u4(i))/sigma_g);
alfa2=double(a2(u1(i),u2(i),u3(i),u4(i))/sigma_g);
alfa3=double(a3(u1(i),u2(i),u3(i),u4(i))/sigma_g);
alfa4=double(a4(u1(i),u2(i),u3(i),u4(i))/sigma_g);
alfa_sum=alfa1^2+alfa2^2+alfa3^2+alfa4^2;
%--Updating design points--%
u1(i+1)=-alfa1*beta(i);
u2(i+1)=-alfa2*beta(i);
u3(i+1)=-alfa3*beta(i);
u4(i+1)=-alfa4*beta(i);
%--------------------------%
conv1=u1(i+1)-u1(i);
conv2=u2(i+1)-u2(i);
conv3=u3(i+1)-u3(i);
conv4=u4(i+1)-u4(i);
conv=sqrt(conv1^2+conv2^2+conv3^2+conv4^2); %Convergence norm

A0(i,:)=double(a0(u1(i),u2(i),u3(i),u4(i)));
A1(i,:)=double(a1(u1(i),u2(i),u3(i),u4(i)));
A2(i,:)=double(a2(u1(i),u2(i),u3(i),u4(i)));
A3(i,:)=double(a3(u1(i),u2(i),u3(i),u4(i)));
A4(i,:)=double(a4(u1(i),u2(i),u3(i),u4(i)));
A0_sorm(i,:)=double(a0_sorm(u1(i),u2(i),u3(i),u4(i)));
B1(i,:)=double(b1(u1(i),u2(i),u3(i),u4(i)));
B2(i,:)=double(b2(u1(i),u2(i),u3(i),u4(i)));
B3(i,:)=double(b3(u1(i),u2(i),u3(i),u4(i)));
B4(i,:)=double(b4(u1(i),u2(i),u3(i),u4(i)));

i=i+1;
end
beta=beta(end); %Reliability beta
%----Design points--------------------------------------------%
U1=transpose(double(u1));
U2=transpose(double(u2));
U3=transpose(double(u3));
U4=transpose(double(u4));
X1=exp(double(T(1,1)*u1+T(1,2)*u2+T(1,3)*u3+T(1,4)*u4)*sigma_log1+mu_log1)';
X2=exp(double(T(2,1)*u1+T(2,2)*u2+T(2,3)*u3+T(2,4)*u4)*sigma_log2+mu_log2)';
X3=exp(double(T(3,1)*u1+T(3,2)*u2+T(3,3)*u3+T(3,4)*u4)*sigma_log3+mu_log3)';
X4=(double(T(4,1)*u1+T(4,2)*u2+T(4,3)*u3+T(4,4)*u4)*sigma_4+mu_4)';

design1 = X1(end);
design2 = X2(end);
design3 = X3(end);
design4 = X4(end);
%------------------------------------------------------------%
%----Finding "SORM-factor"----------------------------%
gradi_star = gradi(u1(end),u2(end),u3(end),u4(end));
gradi_length=double(sqrt(sum(gradi_star.^2))); 

% I, P & H_tilde
P=gradi_length^-2*double(gradi_star)*double(transpose(gradi_star));
H_tilde=I + (beta)*gradi_length^-1*double(hessian(u1(end),u2(end),u3(end),u4(end)));

% SORM factor 
SORM_factor = (det(((I-P)*H_tilde*(I-P))+P))^(-0.5); 
%-----------------------------------------------------%
end