%%%%%%%%%RSM-FORM MAIN SCRIPT%%%%%%%
clc
clear all
%-------------Set material parameters-------------------%
fck=45; %Characteristic concrete strength
fyk=500; %Characteristic steel yield strength
COV_c = 0.15; %Coefficient of variation concrete
COV_s = 0.04; %Coefficient of variation steel yield strength
COV_Ec = 0.15; %Coefficient of variation concrete E-modulus
COV_e1y = 0.15; %Coefficient of variation eccentricity
mu_c = (fck/1.15)*exp(1.645*COV_c); %Mean in-situ concrete compressive strength
mu_s = fyk*exp(1.645*COV_s); %Mean in-situ steel yield strength
mu_Ec = 30000; %Mean concrete youngs modulus
mu_e1y = 40; %Mean eccentricity
%-------------------------------------------------------%
sigma_c = mu_c*COV_c;
sigma_s = mu_s*COV_s;
sigma_Ec = mu_Ec*COV_Ec;
sigma_e1y = mu_e1y*COV_e1y;

Force = 250e3; %Force in [N] for which beta is to be calculated

%---------Lognormal mean and standard deviation--------%
mu_logc=log((mu_c^2)*sqrt(1/(sigma_c^2+mu_c^2)));
mu_logs=log((mu_s^2)*sqrt(1/(sigma_s^2+mu_s^2)));
mu_logEc=log((mu_Ec^2)*sqrt(1/(sigma_Ec^2+mu_Ec^2)));
sigma_logc=sqrt(log((sigma_c^2)/(mu_c^2)+1));
sigma_logs=sqrt(log((sigma_s^2)/(mu_s^2)+1));
sigma_logEc=sqrt(log((sigma_Ec^2)/(mu_Ec^2)+1));
%------------------------------------------------------%
%-----Correlation matrix between the stochastic variables--------%
correlation_matrix = [1 0 0 0;0 1 0 0;0 0 1 0;0 0 0 1];
%----------------------------------------------------------------%
%-----Set starting point for RSM sampling,and f (sample scatter)-----%
design_point_c = [40] ; 
design_point_s = [500]; 
design_point_Ec = [30000];
design_point_e1y = [54];
f = 3.0;
%--------------------------------------------------------------------%

%-----Set convergence norms for RSM and FORM iterations-------%
e_RSM = 0.01; %Convergence norm e_RSM = sqrt((beta(i)-beta(i-1))^2)
e_FORM = 10^-4; % Covergence norm e_FORM = sqrt((xda(j)-xda(j-1))^2+(xdb(j)-xdb(j-1))^2)
%-------------------------------------------------------------%
i=0;  % Iteration number
R=[]; %Resistance vector (increases for every RSM-iteration)
b_vector_2 = []; %Vector containing the coefficients from least squares calculation from previous RSM-iteraions
beta=[];
alfa1=[];
alfa2=[];
alfa3=[];
alfa4=[];
x1={}; x2={}; x3={}; x4={}; u1={}; u2={}; u3={}; u4={};
CONV=1;

while CONV >= e_RSM %Check for convergence
        i=i+1; %Update iteration number
        
        
        %-----Writing e1y to python script-------%
        [e1y] = RSM_sampling_e1y(design_point_e1y(i),sigma_e1y,mu_e1y,f);
        write_to_python(e1y)
        system('Path to _RUNDIANA_e1y.bat')
        %----------------------------------------%
        
        
        %1) Write material data from the given sample points to .dat
        %   files for DIANA
        
        [fc, fy, Ec, fct, Gc, Gf, kfy, ey, eu] = RSM_sampling(design_point_c(i),design_point_s(i),design_point_Ec(i),f,sigma_logc,sigma_logs,sigma_logEc,mu_logc,mu_logs,mu_logEc,fck,COV_c);
        
        %2) Run analyses via batch, and extract resistances
        
        %%%%%%%%%%%%%%%%%Running batch file%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Specify path to .BAT-file after the exclamation mark
        !Path to _RUNDIANA.bat
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
        %3) Append new resistances to the R-vector
        [Ri]=Find_capacity();
        R=vertcat(R,Ri(:,1));
        
        %4) Generate a new response surface
        
        [b_vector_2(:,i),a_vector] = RSM_generation(R,design_point_c,design_point_s,design_point_Ec,design_point_e1y,f,COV_c,sigma_logc,sigma_logs,sigma_logEc, sigma_e1y,mu_logc,mu_logs,mu_logEc, mu_e1y,fck);
        
        
        
        %5) Run FORM on the response surface
        
        [design_point_c(i+1),design_point_s(i+1),design_point_Ec(i+1),design_point_e1y(i+1),beta(i),alfa1(i),alfa2(i),alfa3(i),alfa4(i),x1{i},x2{i},x3{i},x4{i},u1{i},u2{i},u3{i},u4{i},A0{i},A1{i},A2{i},A3{i},A4{i},A0_sorm{i},B1{i},B2{i},B3{i},B4{i},SORM_factor(i)] = FORM(mu_logc,mu_logs,mu_logEc,mu_e1y,Force,b_vector_2(:,i),sigma_logc,sigma_logs,sigma_logEc,sigma_e1y,design_point_c(i),design_point_s(i),design_point_Ec(i),design_point_e1y(i),correlation_matrix);        
        pf_0 = normcdf(-beta(i),0,1); %FORM probability of failure
        Pf(i)=SORM_factor(i)*pf_0;  %SORM probability of failure
        if i==1
            CONV=1;
        else
            CONV=sqrt((beta(i)-beta(i-1))^2); %Convergence norm
        end
end    

fprintf('Reliability form-beta: %6.2f \n',beta(i))
fprintf('Design point fcd: %6.2f\n',design_point_c(i+1))
fprintf('Design point fyd: %6.2f\n',design_point_s(i+1))
fprintf('Design point Ecd: %6.2f\n',design_point_Ec(i+1))
fprintf('Probability of failure FORM: %6.10f\n',pf_0)
fprintf('Probability of failure SORM: %6.10f\n',Pf(end))
fprintf('Number of RSM-iterations: %6.2f\n',i)