# OPEN NEW PROJECT
closeProject()
PATH="/RSM_FORM_5VAR/"
navn = "7" #NAVN PÅ ANALYSE OG FILER
newProject( navn, 10 )
setModelAnalysisAspects( [ "STRUCT" ] )
setModelDimension( "2D" )
setDefaultMeshOrder( "QUADRATIC" )
setDefaultMidSideNodeLocation( "LINEAR" )
setDefaultMesherType( "HEXQUAD" )
setUnit( "LENGTH", "MM" )
setUnit( "FORCE", "N" )

import os
from math import pi

# MATERIAL PARAMETRIC STUDY VARIABLES

fc = 50.08 #[MPa] COMPRESSIVE STRENGTH
Ec = 35.67186e3 #[MPa] YOUNG'S MODULUS
fct = 3.46 #[MPa] TENSILE STRENGTH
poisson_c = 0.15 #INITIAL POISSON RATIO
Gf = 0.148 #[N/mm] FRACTURE ENERGY
Gc = 37.00 #[N/mm] COMPRESSIVE FRACTURE ENERGY

Es = 200000 #[MPa] YOUNG'S MODULUS
Eplate = 1000000 # [MPa] STIFFNESS LOADING PLATE
fy = 534.01 #YIELD STRESS
kfy = 1.08*fy #ULTIMATE STRESS
poisson_s = 0.3 #POISSON'S RATIO 
yield_strain = 0.00267
ultimate_strain = 0.05
ultimate_plastic_strain = ultimate_strain-yield_strain




# ANALYSIS PARAMETERS==================================================================================================================================================
ITEMAX = 50 #Max number of iterations
CONFORCE = 0.01 #Convergence criteria - Force
CONDISP = 0.001 #Convergence criteria - Displacement
CONEN = 0.0001 #Convergence criteria - Energy
ABORT = 1000 #Abort criterion
LOADSTEP="0.012(75)" #Size and number of loadsteps

#DEFINE COLUMN AND PLATEN GEOMETRIES

HEIGHT = 240 
WIDTH = 150
LENGTH = 3800

CX1 = 33 #SEE FIG. 1
CX2 = 58 #SEE FIG. 1
CX3 = 58 #SEE FIG. 1
CY1 = 33 #SEE FIG. 1
CY2 = 84 #SEE FIG. 1
LENGTH_COMPRESSION = 600 #LONGITUDNIAL LENGTH OF COMPRESSION REINFORCEMENT
PLATE_THICKNESS = 20 #THICKNESS OF LOADING PLATENS

#DEFINE STIRRUP GEOMETRY
CC1 = 15 #DISTANCE FROM EDGE TO FIRST STIRRUP
CC2 = 35 #CENTER DISTANCE BETWEEN STIRRUPS IN FIRST ROW
CC3 = 45 #CENTER DISTANCE BETWEEN STIRRUPS IN SECOND ROW
CC4 = 150 #CENTER DISTANCE BETWEEN MIDDLE ROW OF STIRRUPS 
CC5 = 75 #DISTANCE BETWEEN SECOND ROW OF STIRRUPS AND MIDDLE ROW OF STIRRUPS

N1 = 6 #NUMBER OF STIRRUPS IN FIRST ROW
N2 = 8 #NUMBER OF STIRRUPS IN SECOND ROW
N3 = 17 #NUMBER OF STIRRUPS IN MIDDLE ROW

#############FIG 1###############
# CX1,CX2,CX3,CY1 OG CY2 ER SENTERAVSTANDER
#       _____________________________________  
#      |                                     |  
#	   |   O       O           O        O    |  _
#	   |                                     |  |
#	   |                                     |  | 
#	   |                                     |  | CY2
#	   |                                     | _|
#	   |   O       O           O        O    |  | CY1
#	   |_____________________________________| _| 
#       
#	   |---|-------|-----------|
#        CX1   CX2     CX3


#DEFINE REINFORCEMENT AREAS
DIAMLONG = 14 #LONGITUDINAL REINFORCEMENT DIAMATER
ASL = pi/4*DIAMLONG**2
DIAMSTIRR = 6 #STIRRUP DIAMETER
ASS = pi/4*DIAMSTIRR**2


#DEFINE DISPLACEMENT PARAMETERS
TOTALDISPLACEMENT=-5
ECCENTRICIY = 4.81400e+01


addMaterial( "Concrete", "CONCR", "TSCR", [] )
setParameter( MATERIAL, "Concrete", "LINEAR/ELASTI/YOUNG", Ec )
setParameter( MATERIAL, "Concrete", "LINEAR/ELASTI/POISON", poisson_c )

setParameter( MATERIAL, "Concrete", "MODTYP/TOTCRK", "ROTATE" )
setParameter( MATERIAL, "Concrete", "MODTYP/CBSPEC", "GOVIND" )

setParameter( MATERIAL, "Concrete", "TENSIL/TENCRV", "EXPONE" )
setParameter( MATERIAL, "Concrete", "TENSIL/TENSTR", fct )
setParameter( MATERIAL, "Concrete", "TENSIL/GF1", Gf )
setParameter( MATERIAL, "Concrete", "TENSIL/POISRE/POIRED", "DAMAGE" )

#setParameter( MATERIAL, "Concrete", "COMPRS/COMCRV", "EC2" ) EC2-1-1
#setParameter( MATERIAL, "Concrete", "COMPRS/COMSTR", fc )
#setParameter( MATERIAL, "Concrete", "COMPRS/EPSC1", ec1 )
#setParameter( MATERIAL, "Concrete", "COMPRS/EPSCU", ecu1 )
#setParameter( MATERIAL, "Concrete", "COMPRS/YOUNCM", Ec )


setParameter( MATERIAL, "Concrete", "COMPRS/COMCRV", "PARABO" ) #Parabolic
setParameter( MATERIAL, "Concrete", "COMPRS/COMSTR", fc)
setParameter( MATERIAL, "Concrete", "COMPRS/GC", Gc )
setParameter( MATERIAL, "Concrete", "COMPRS/REDUCT/REDCRV", "VC1993" )
setParameter( MATERIAL, "Concrete", "COMPRS/REDUCT/REDMIN", 0.4)
setParameter( MATERIAL, "Concrete", "COMPRS/CONFIN/CNFCRV", "VECCHI" )


addMaterial( "Reinforcement steel", "REINFO", "VMISES", [] )
setParameter( MATERIAL, "Reinforcement steel", "LINEAR/ELASTI/YOUNG", Es )
setParameter( MATERIAL, "Reinforcement steel", "PLASTI/YLDTYP", "KAPSIG" ) #Plastic strain-yield stress
setParameter( MATERIAL, "Reinforcement steel", "PLASTI/HARDI2/KAPSIG", [] ) #Add stress strain diagram after yield
setParameter( MATERIAL, "Reinforcement steel", "PLASTI/HARDI2/KAPSIG", [ 0, fy, ultimate_plastic_strain, kfy ] ) 
setParameter( MATERIAL, "Reinforcement steel", "PLASTI/HARDEN", "STRAIN" ) #Strain hardening
setParameter( MATERIAL, "Reinforcement steel", "PLASTI/HARTYP", "ISOTRO" ) #Hardening type: Isotropic hardening


	#LOADING PLATENS
addMaterial( "Loading plate steel", "MCSTEL", "ISOTRO", [] )
setParameter( MATERIAL, "Loading plate steel", "LINEAR/ELASTI/YOUNG", Eplate )
setParameter( MATERIAL, "Loading plate steel", "LINEAR/ELASTI/POISON", poisson_s )

#DEFINE MESH PROPERTIES
ELEMENT_SIZE = WIDTH/4 #AVERAGE ELEMENT DIMENSION

#CREATE CONCRETE COLUMN
createSheet( "Concrete column", [[ 0, LENGTH/2, 0 ],[ 0, LENGTH, 0 ],[ WIDTH, LENGTH, 0 ],[ WIDTH, LENGTH/2, 0 ]] )
#CREATING LOADING AND SUPPORT PLATENS
THICKNESS=PLATE_THICKNESS
createSheet( "Top loading platen", [[ 0, LENGTH, 0 ],[ 0, LENGTH+THICKNESS, 0 ],[ WIDTH/2+ECCENTRICIY, LENGTH+THICKNESS, 0 ],[ WIDTH+50, LENGTH+THICKNESS, 0 ],[ WIDTH+50, LENGTH, 0 ]] )


#CREATING COMPOSED LINE
createLine( "Composed line", [ WIDTH/2, LENGTH/2, 0 ], [ WIDTH/2, LENGTH, 0 ] )

#CREATING LONGITUDINAL REINFORCEMENT
createLine( "Long reinf 1", [ CY1, LENGTH/2, 0 ], [ CY1, LENGTH, 0 ] )
createLine( "Long reinf 2", [ WIDTH-CY1, LENGTH/2, 0 ], [ WIDTH-CY1, LENGTH, 0 ] )
createLine( "Long reinf compression 1", [ CY1, LENGTH+PLATE_THICKNESS, 0 ], [ CY1, LENGTH-LENGTH_COMPRESSION, 0 ] )
createLine( "Long reinf compression 2", [ WIDTH-CY1, LENGTH+PLATE_THICKNESS, 0 ], [ WIDTH-CY1, LENGTH-LENGTH_COMPRESSION, 0 ] )

LONGREINF = ["Long reinf 1","Long reinf 2","Long reinf compression 1","Long reinf compression 2"]

#CREATING STIRRUPS
SNUM = 1
COMPRESSION_STIRRUP = [] #SHAPELIST FOR COMPRESSION STIRRUPS
for i in range (0,N1):
	LINENAME = 'COMPRESSION_STIRRUP{}'.format(SNUM)
	COMPRESSION_STIRRUP.append(LINENAME)
	createLine( LINENAME, [ CY1, LENGTH-(CC1+i*CC2), 0 ], [ WIDTH-CY1, LENGTH-(CC1+i*CC2), 0 ] )
	SNUM = SNUM+1
	YCOORD1 = LENGTH-(CC1+i*CC2)

for i in range(1,N2+1):
	LINENAME = 'COMPRESSION_STIRRUP{}'.format(SNUM)
	COMPRESSION_STIRRUP.append(LINENAME)
	createLine( LINENAME, [ CY1, YCOORD1-(i*CC3), 0 ], [ WIDTH-CY1, YCOORD1-(i*CC3), 0 ] )
	SNUM = SNUM+1
	YCOORD2 = YCOORD1-i*CC3
SNUM2 = 1
STIRRUP = [] #SHAPELIST FOR MIDDLE STIRRUPS

for i in range(0,int(N3/2)+1):
	LINENAME = 'STIRRUP{}'.format(SNUM2)
	STIRRUP.append(LINENAME)
	createLine( LINENAME, [ CY1, YCOORD2-(i*CC4+CC5), 0 ], [ WIDTH-CY1, YCOORD2-(i*CC4+CC5), 0 ] )
	SNUM2 = SNUM2+1
	YCOORD3 = YCOORD2-(i*CC4+CC5)


#CREATING BOUNDARY CONDITIONS AND LOAD

addSet( GEOMETRYSUPPORTSET, "BC top" )
createPointSupport( "BC top", "BC top" )
setParameter( GEOMETRYSUPPORT, "BC top", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "BC top", "TRANSL", [ 1, 1, 0 ] )
setParameter( GEOMETRYSUPPORT, "BC top", "ROTATI", [ 0, 0, 0 ] )
attach( GEOMETRYSUPPORT, "BC top", "Top loading platen", [[ WIDTH/2+ECCENTRICIY, LENGTH+THICKNESS, 0 ]] )

addSet( GEOMETRYSUPPORTSET, "BC bottom" )
createLineSupport( "BC bottom", "BC bottom" )
setParameter( GEOMETRYSUPPORT, "BC bottom", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "BC bottom", "TRANSL", [ 0, 1, 0 ] )
setParameter( GEOMETRYSUPPORT, "BC bottom", "ROTATI", [ 0, 0, 0 ] )
attach( GEOMETRYSUPPORT, "BC bottom", "Concrete column", [[ WIDTH/2, 1900, 0 ]] )

addSet( GEOMETRYLOADSET, "Prescribed displacement" )
createPointLoad( "Prescribed displacement", "Prescribed displacement" )
setParameter( GEOMETRYLOAD, "Prescribed displacement", "LODTYP", "DEFORM" )
setParameter( GEOMETRYLOAD, "Prescribed displacement", "DEFORM/TR/VALUE", TOTALDISPLACEMENT )
setParameter( GEOMETRYLOAD, "Prescribed displacement", "DEFORM/TR/DIRECT", 2 )
attach( GEOMETRYLOAD, "Prescribed displacement", "Top loading platen", [[ WIDTH/2+ECCENTRICIY, LENGTH+THICKNESS, 0 ]] )


#ASSIGNING ELEMENT PROPERTIES

#COMPRESSION STIRRUPS
addGeometry( "Element geometry 1", "RELINE", "REBAR", [] )
rename( GEOMET, "Element geometry 1", "Compression stirrup" )
setParameter( GEOMET, "Compression stirrup", "REIEMB/CROSSE", 4*ASS )
setReinforcementAspects( COMPRESSION_STIRRUP )
assignMaterial( "Reinforcement steel", SHAPE, COMPRESSION_STIRRUP )
assignGeometry( "Compression stirrup", SHAPE, COMPRESSION_STIRRUP )
resetElementData( SHAPE, COMPRESSION_STIRRUP )
setReinforcementDiscretization( COMPRESSION_STIRRUP , "ELEMENT" )
#STIRRUPS
addGeometry( "Element geometry 2", "RELINE", "REBAR", [] )
rename( GEOMET, "Element geometry 2", "stirrups" )
setParameter( GEOMET, "stirrups", "REIEMB/CROSSE", 2*ASS )
setReinforcementAspects( STIRRUP )
assignMaterial( "Reinforcement steel", SHAPE, STIRRUP )
assignGeometry( "stirrups", SHAPE, STIRRUP )
resetElementData( SHAPE, STIRRUP )
setReinforcementDiscretization( STIRRUP , "ELEMENT" )
#LONGITUDINAL REINFORCEMENT
addGeometry( "Element geometry 3", "RELINE", "REBAR", [] )
rename( GEOMET, "Element geometry 3", "Longitudinal reinforcemnt" )
setParameter( GEOMET, "Longitudinal reinforcemnt", "REIEMB/CROSSE", 2*ASL )
setReinforcementAspects( LONGREINF )
assignMaterial( "Reinforcement steel", SHAPE, LONGREINF )
assignGeometry( "Longitudinal reinforcemnt", SHAPE, LONGREINF )
resetElementData( SHAPE, LONGREINF )
setReinforcementDiscretization( LONGREINF , "ELEMENT" )
#CONCRETE BEAM
addGeometry( "Element geometry 4", "SHEET", "MEMBRA", [] )
rename( GEOMET, "Element geometry 4", "Concrete column" )
setParameter( GEOMET, "Concrete column", "THICK", HEIGHT )
clearReinforcementAspects( [ "Concrete column" ] )
setElementClassType( SHAPE, [ "Concrete column" ], "MEMBRA" )
assignMaterial( "Concrete", SHAPE, [ "Concrete column" ] )
assignGeometry( "Concrete column", SHAPE, [ "Concrete column" ] )
resetElementData( SHAPE, [ "Concrete column" ] )
#LOADING PLATENS
addGeometry( "Element geometry 5", "SHEET", "MEMBRA", [] )
setParameter( GEOMET, "Element geometry 5", "THICK", HEIGHT )
clearReinforcementAspects( [ "Top loading platen" ] )
setElementClassType( SHAPE, [ "Top loading platen" ], "MEMBRA" )
assignMaterial( "Loading plate steel", SHAPE, [ "Top loading platen" ] )
assignGeometry( "Element geometry 5", SHAPE, [ "Top loading platen" ] )
resetElementData( SHAPE, [ "Top loading platen" ] )
#COMPOSED LINE 
addGeometry( "Element geometry 6", "LINE", "COMLIN", [] )
rename( GEOMET, "Element geometry 6", "Composed line" )
setParameter( GEOMET, "Composed line", "LOCAXS", True )
setParameter( GEOMET, "Composed line", "LOCAXS/ZAXIS", [ 0, 0, 1 ] )
setParameter( GEOMET, "Composed line", "LOCAXS/ZAXIS", [ 1, 0, 0 ] )
setParameter( GEOMET, "Composed line", "LOCAXS/ZAXIS", [ 1, 0, 0 ] )
clearReinforcementAspects( [ "Composed line" ] )
setElementClassType( SHAPE, [ "Composed line" ], "COMLIN" )
assignMaterial( "Concrete", SHAPE, [ "Composed line" ] )
assignGeometry( "Composed line", SHAPE, [ "Composed line" ] )
resetElementData( SHAPE, [ "Composed line" ] )


#MESHING
setElementSize( [ "Concrete column", "Top loading platen" ], ELEMENT_SIZE, -1, True )
setMesherType( [ "Concrete column", "Top loading platen" ], "HEXQUAD" )
setMidSideNodeLocation( [ "Concrete column", "Top loading platen" ], "LINEAR" )
setElementSize( [ "Composed line" ], ELEMENT_SIZE, -1, True )
setMesherType( [ "Composed line" ], "HEXQUAD" )
setMidSideNodeLocation( [ "Composed line" ], "LINEAR" )
generateMesh( [] )

#SET UP ANALYSIS
addAnalysis( navn )
addAnalysisCommand( navn, "NONLIN", "Structural nonlinear" )

# Geometric nonlinearity
addAnalysisCommandDetail( navn, "Structural nonlinear", "TYPE/GEOMET" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "TYPE/GEOMET", True )
setAnalysisCommandDetail( navn, "Structural nonlinear", "TYPE/GEOMET/GEOTYP", "TOTAL" )

# Evaluate model
setAnalysisCommandDetail( navn, "Structural nonlinear", "TYPE/PHYSIC/CREEP", False )
setAnalysisCommandDetail( navn, "Structural nonlinear", "TYPE/PHYSIC/HYPERE", False )
setAnalysisCommandDetail( navn, "Structural nonlinear", "TYPE/PHYSIC/VISCOE", False )
setAnalysisCommandDetail( navn, "Structural nonlinear", "TYPE/PHYSIC/VISCOP", False )
setAnalysisCommandDetail( navn, "Structural nonlinear", "TYPE/PHYSIC/INTERF", True )
setAnalysisCommandDetail( navn, "Structural nonlinear", "TYPE/PHYSIC/SHRINK", False )
setAnalysisCommandDetail( navn, "Structural nonlinear", "TYPE/PHYSIC/TEMPER", False )
setAnalysisCommandDetail( navn, "Structural nonlinear", "TYPE/PHYSIC/CONCEN", False )
setAnalysisCommandDetail( navn, "Structural nonlinear", "TYPE/PHYSIC/MATURI", False )
setAnalysisCommandDetail( navn, "Structural nonlinear", "TYPE/PHYSIC/CORROS", False )
setAnalysisCommandDetail( navn, "Structural nonlinear", "TYPE/PHYSIC/PML", False )

# Load steps
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/LOAD/STEPS/STEPTY", "EXPLIC" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/LOAD/STEPS/EXPLIC/SIZES", LOADSTEP )
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/LOAD/STEPS/EXPLIC/ARCLEN", False )

# Logging information
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/LOGGIN/REPORT/AMOUNT", "FULL" ) #Detail level - Full
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/LOGGIN/REPORT/TERMIN", "STEP" ) #Log at each step

# Equilibrium iteration
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/ITERAT/METHOD/METNAM", "NEWTON" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/ITERAT/METHOD/NEWTON/TYPNAM", "REGULA" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/ITERAT/METHOD/NEWTON/START", "TANGEN" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/ITERAT/MAXITE", ITEMAX )
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/ITERAT/LINESE", False ) #Line search
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/ITERAT/CONVER/DISPLA", True )
addAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/ITERAT/CONVER/ENERGY")
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/ITERAT/CONVER/FORCE", False )
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/ITERAT/CONVER/DISPLA/TOLCON", CONDISP)
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/ITERAT/CONVER/DISPLA/TOLABT", ABORT )
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/ITERAT/CONVER/DISPLA/NOCONV", "CONTIN" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/ITERAT/CONVER/ENERGY/TOLCON", CONEN) 
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/ITERAT/CONVER/ENERGY/TOLABT", ABORT )
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/ITERAT/CONVER/ENERGY/NOCONV", "CONTIN" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "EXECUT(1)/ITERAT/CONVER/SIMULT", False ) 

# Solution method
setAnalysisCommandDetail( navn, "Structural nonlinear", "SOLVE/TYPE", "PARDIS" )

#SPECIFY WHICH OUTPUT TO BE EXTRACTED FROM THE ANALYSIS
#For tabulated


DISPCOORD = [WIDTH, LENGTH/2,0]
DISPNODE = findNearestNodes([DISPCOORD])
FORCENODES = findNodesInBox(-1,WIDTH+1,LENGTH/2-1,LENGTH/2+1,0,0)
forcenodes = []

for i in range(0,len(FORCENODES)):
	forcenodes.append(str(FORCENODES[i]))

addElementGroup('Composed line1',['Composed line'])
z=elementsInGroup('Composed line1')
z=list(z)
z.sort()
element = z[0]
DISPNODE = str(DISPNODE[0])
#FORCENODE1 = str(FORCENODE1[0])
element = str(element)

addElementGroup('Concrete column1',['Concrete column'])
x=elementsInGroup('Concrete column1')
x=list(x)
x.sort()
firstelement = x[0]
lastelement = -x[len(x)-1]
firstelement=str(firstelement)
lastelement=str(lastelement)
elemrange=firstelement+lastelement

# Tabulated output
# MOMENT
addAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(2)/DEVICE", "TABULA" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(2)/SELECT/MODSEL", "USER" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(2)/SELECT/NODES(1)/RNGNRS", "NONE" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(2)/SELECT/ELEMEN(1)/RNGNRS", [elemrange,element] )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(2)/SELECT/REINFO(1)/RNGNRS", "ALL" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(2)/SELTYP", "USER" )
addAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(2)/USER" )
addAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(2)/USER/STRESS(1)/TOTAL/MOMENT/LOCAL" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(2)/USER/STRESS(1)/TOTAL/MOMENT/LOCAL/COMP", [ "Y" ] ) 
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(2)/LAYOUT/LINPAG", 1999999999 )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(2)/APPEND", False )

# FORCE
addAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(3)/DEVICE", "TABULA" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(3)/SELECT/MODSEL", "USER" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(3)/SELECT/NODES(1)/RNGNRS", forcenodes )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(3)/SELECT/ELEMEN(1)/RNGNRS", "NONE" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(3)/SELECT/REINFO(1)/RNGNRS", "NONE" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(3)/SELTYP", "USER" )
addAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(3)/USER" )
addAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(3)/USER/FORCE(1)/REACTI/TRANSL" )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(3)/USER/FORCE(1)/REACTI/TRANSL/GLOBAL/COMP", [ "Y" ] )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(3)/LAYOUT/LINPAG", 1999999999 )
setAnalysisCommandDetail( navn, "Structural nonlinear", "OUTPUT(3)/APPEND", False )



# EXPORT .DAT- AND .DCF-FILE
navn2 = ".dat"
navn3 = navn+navn2
exportModel( navn3, 5 )
navn4 = ".dcf"
navn5 = navn+navn4
saveAnalysisCommands( navn, navn5)
saveProject()

