%%%%%%%%%RSM-FORM MAIN SCRIPT%%%%%%%
clc
clear all
name = 'C30'; %Analysis name
%-------Set material parameters-------------------%
fck=30;
fyk=500;
COV_c = 0.15; %Concrete coefficient of variation
COV_s = 0.04; %Steel coefficient of variation
COV_Ec = 0.1582; %Ec coefficient of variation
COV_e1y = 0.13435; %Coefficient of variation eccentricity
COV_Force = 0.2; % Coefficient of variation of Force
mu_c = (fck/1.15)*exp(1.645*COV_c); %Mean in-situ concrete compressive strength
mu_s = fyk*exp(1.645*COV_s); %Mean in-situ steel yield strength
mu_Ec = 31586; %Mean concrete youngs modulus
mu_e1y = 40; %mean eccentricity
mu_Force = 120000; %Mean Force
%Standard deviations:
sigma_c = mu_c*COV_c;
sigma_s = mu_s*COV_s;
sigma_Ec = mu_Ec*COV_Ec;
sigma_e1y = COV_e1y*mu_e1y;
sigma_Force = mu_Force*COV_Force;
%-------------------------------------------------%

%------Lognormal mean and standard deviation------%
mu_logc=log((mu_c^2)*sqrt(1/(sigma_c^2+mu_c^2)));
mu_logs=log((mu_s^2)*sqrt(1/(sigma_s^2+mu_s^2)));
mu_logEc=log((mu_Ec^2)*sqrt(1/(sigma_Ec^2+mu_Ec^2)));

sigma_logc=sqrt(log((sigma_c^2)/(mu_c^2)+1));
sigma_logs=sqrt(log((sigma_s^2)/(mu_s^2)+1));
sigma_logEc=sqrt(log((sigma_Ec^2)/(mu_Ec^2)+1));

%-----Correlation matrix between the stochastic variables--------------%
correlation_matrix = [1 0 0 0 0;0 1 0 0 0;0 0 1 0 0;0 0 0 1 0;0 0 0 0 1];
%----------------------------------------------------------------------%
%-------Set starting point for RSM sampling,and f (sample scatter)--------%
design_point_c = [30] ; %fc
design_point_s = [500]; %fy
design_point_Ec = [25000]; %Ec
design_point_e1y = [48.14]; %e1y
design_point_Force = [190000]; %Force
f = 3.0;
%-------------------------------------------------------------------------%

%-----Set convergence norms for RSM and FORM iterations---%
e_RSM = 0.01; %Convergence norm e_RSM = sqrt((beta(i)-beta(i-1))^2)
e_FORM = 10^-4; % Covergence norm e_FORM = sqrt((xda(j)-xda(j-1))^2+(xdb(j)-xdb(j-1))^2)
%---------------------------------------------------------%
i=0;  % Iteration number
R=[]; %Resistance vector (increases for every RSM-iteration)
b_vector_2 = []; %Vector containing the coefficients from least squares calculation from previous RSM-iteraions
beta=[];
alfa1=[];
alfa2=[];
alfa3=[];
alfa4=[];
alfa5=[];
x1={}; x2={}; x3={}; x4={}; x5={}; u1={}; u2={}; u3={}; u4={}; u5={};
CONV=1;


while CONV >= e_RSM %Check for convergence
        i=i+1; %Update iteration number
        %Writing e1y to python script and generate new .dat-files
        [e1y] = RSM_sampling_e1y(design_point_e1y(i),sigma_e1y,mu_e1y,f);
        write_to_python(e1y)
        system('PATH TO _RUNDIANA_e1y.bat')

        %1) Write material parameters from sample points to .dat-files
        
        [fc, fy, Ec, fct, Gc, Gf, kfy, ey, eu] = RSM_sampling(design_point_c(i),design_point_s(i),design_point_Ec(i),f,sigma_logc,sigma_logs,sigma_logEc,mu_logc,mu_logs,mu_logEc,fck,COV_c);
        
        %2) Run analyses in DIANA via batch, and extract resistances
        
        %--------Running batch file------------------%
        %Specify path to .BAT-file after the exclamation mark
        !Path to _RUNDIANA.bat
        %--------------------------------------------%
        
        %3) Append new resistances to the R-vector
        [Ri]=Find_capacity();
        R=vertcat(R,Ri(:,1));
        
        %4) Generate response surface
        
        [b_vector_2(:,i),a_vector] = RSM_generation(R,design_point_c,design_point_s,design_point_Ec,design_point_e1y,f,COV_c,sigma_logc,sigma_logs,sigma_logEc,sigma_e1y,mu_logc,mu_logs,mu_logEc,mu_e1y,fck);
        
        
        
        %5) Run FORM
        [design_point_c(i+1),design_point_s(i+1),design_point_Ec(i+1),design_point_e1y(i+1),design_point_Force(i+1),beta(i),alfa1(i),alfa2(i),alfa3(i),alfa4(i),alfa5(i),x1{i},x2{i},x3{i},x4{i},x5{i},u1{i},u2{i},u3{i},u4{i},u5{i},A0{i},A1{i},A2{i},A3{i},A4{i},A5{i},A0_sorm{i},B1{i},B2{i},B3{i},B4{i},B5{i},SORM_factor(i)] = FORM(mu_logc,mu_logs,mu_logEc,mu_e1y,mu_Force,b_vector_2(:,i),sigma_logc,sigma_logs,sigma_logEc,sigma_e1y,sigma_Force,design_point_c(i),design_point_s(i),design_point_Ec(i),design_point_e1y(i),design_point_Force(i),correlation_matrix);        
        pf_0 = normcdf(-beta,0,1); 
        Pf(i)=SORM_factor(i)*pf_0(i); 
        if i==1
            CONV=1;
        else
            CONV=sqrt((beta(i)-beta(i-1))^2); %Convergence criterion
        end
end    
save(name) %Saving workspace
fprintf('Reliability form-beta: %6.2f \n',beta(i))
fprintf('Design point fcd: %6.2f\n',design_point_c(i+1))
fprintf('Design point fyd: %6.2f\n',design_point_s(i+1))
fprintf('Design point Ecd: %6.2f\n',design_point_Ec(i+1))
fprintf('Design point e1y: %6.2f\n',design_point_e1y(i+1))
fprintf('Probability of failure FORM: %6.10f\n',pf_0)
fprintf('Probability of failure SORM: %6.10f\n',Pf)
fprintf('Number of RSM-iterations: %6.2f\n',i)