function [xdesign,ydesign,beta,alfa1,alfa2,X1,X2,U1,U2,A0,A1,A2,B1,B2,Pf,A0_SORM] = SORM(mu_logc,mu_logs,b_vector,Force,sigma_logc,sigma_logs,start1,start2)
%%%%SORM-script%%%%%%

syms U1 U2
G(U1,U2)=[1 exp(U1*sigma_logc+mu_logc) exp(U2*sigma_logs+mu_logs) (exp(U1*sigma_logc+mu_logc))^2 (exp(U2*sigma_logs+mu_logs))^2 (exp(U1*sigma_logc+mu_logc))*(exp(U2*sigma_logs+mu_logs))]*b_vector-Force; %Limit state
%----Approximating limit state by taylor series-----%
a1=diff(G,U1);
a2=diff(G,U2);
b1=0.5*diff(a1,U1);
b2=0.5*diff(a2,U2);
a0=G-a1*U1-a2*U2;
a0_sorm=G-a1*U1-a2*U2+b1*U1^2+b2*U2^2;
%---------------------------------------------------%
%----Straing points of iterations------%
u1(1)=(log(start1)-mu_logc)/sigma_logc;
u2(1)=(log(start2)-mu_logs)/sigma_logs;
%--------------------------------------%

% Gradient and Hessian
gradi=[a1;a2];
hessian =([diff(a1,U1) diff(a1,U2); diff(a2,U1) diff(a2,U2)]);
I=eye(2,2);

i=1;
conv=1;
while conv>10^-6 %Check for convergence
mu_g=double(a0(u1(i),u2(i)));
sigma_g=double(sqrt(a1(u1(i),u2(i))^2+a2(u1(i),u2(i))^2));
beta=double(mu_g/sigma_g);
alfa1=double(a1(u1(i),u2(i))/sigma_g);
alfa2=double(a2(u1(i),u2(i))/sigma_g);
alfa_sum=alfa1^2+alfa2^2;
%---Updating design points----%
u1(i+1)=-alfa1*beta;
u2(i+1)=-alfa2*beta;
%-----------------------------%
%---Calculating SORM-factor and probability of failure-----%
gradi_star=gradi(u1(i+1),u2(i+1));
gradi_length=double(sqrt(sum(gradi_star.^2))); 
% P & H_tilde
P=gradi_length^-2*double(gradi_star)*double(transpose(gradi_star));
H_tilde=I + (beta)*gradi_length^-1*double(hessian(u1(i+1),u2(i+1)));

% SORM factor & Pr(F)
SORM_factor1 = (det(((I-P)*H_tilde*(I-P))+P))^(-0.5); 
pf_0 = normcdf(-beta,0,1); %FORM probability of failure
Pf1(i+1)=SORM_factor1*pf_0; %SORM probability of failure
%----------------------------------------------------------%
conv=sqrt((u1(i+1)-u1(i))^2+(u2(i+1)-u2(i))^2); %Convergence criterion

A0(i,:)=double(a0(u1(i),u2(i)));
A1(i,:)=double(a1(u1(i),u2(i)));
A2(i,:)=double(a2(u1(i),u2(i)));
B1(i,:)=double(b1(u1(i),u2(i)));
B2(i,:)=double(b2(u1(i),u2(i)));
A0_SORM(i,:)=double(a0_sorm(u1(i),u2(i)));
i=i+1;
end
%-------Design points and probability of failure--------%
x1=double(exp(u1*sigma_logc+mu_logc));
x2=double(exp(u2*sigma_logs+mu_logs));
U1=transpose(double(u1));
U2=transpose(double(u2));
X1=transpose(double(x1));
X2=transpose(double(x2));
xdesign = double(exp(u1(end)*sigma_logc+mu_logc));
ydesign = double(exp(u2(end)*sigma_logs+mu_logs));
Pf=Pf1(end);
%-------------------------------------------------------%
end