%%%%%%%%%RSM-FORM MAIN SCRIPT%%%%%%%
clc
clear all
%----------Set variable parameters--------------------%
% Concrete strength, fc
fck=45; %Characteristic
COV_c = 0.15; %Concrete coefficient of variation
mu_c = (fck/1.15)*exp(1.645*COV_c); %Mean in-situ concrete compressive strength
sigma_c=mu_c*COV_c; %Std. deviation of fc
mu_logc=log((mu_c^2)*sqrt(1/(sigma_c^2+mu_c^2))); %Lognormal mean fc
sigma_logc=sqrt(log((sigma_c^2)/(mu_c^2)+1)); %Lognormal std. deviation fc

% Reinforcement yield strength, fy
fyk=500; %Characteristic
COV_s = 0.04; %Steel coefficient of variation
mu_s = fyk*exp(1.645*COV_s); %Mean in-situ steel yield strength
sigma_s=mu_s*COV_s; %Std. deviation fy
mu_logs=log((mu_s^2)*sqrt(1/(sigma_s^2+mu_s^2))); %Lognormal mean fy
sigma_logs=sqrt(log((sigma_s^2)/(mu_s^2)+1)); %Lognormal std. deviation fy

% Concrete stiffness, Ec
COV_E=0.1582; mu_E=35671.55; sigma_E=mu_E*COV_E;
mu_logE=log((mu_E^2)*sqrt(1/(sigma_E^2+mu_E^2))); %Lognormal mean Ec
sigma_logE=sqrt(log((sigma_E^2)/(mu_E^2)+1)); %Lognormal std. deviation Ec

% Eccentricity, e1y
COV_e=0.13435; mu_e=40; sigma_e=mu_e*COV_e;

% Load, N
COV_N=0.2; mu_N=150e3; sigma_N=mu_N*COV_N;

%------Set starting point for RSM sampling,and f (sample scatter)---------%
x1d = [45] ; %fc
x2d = [530]; %fy
x3d = [30e3]; %Ec
x4d = [45]; %e1y
x5d = [240]; %N
f = 5;
%-------------------------------------------------------------------------%

%-------Set convergence norms for RSM and FORM iterations--------%
e_RSM = 0.01; %Convergence norm e_RSM = sqrt((beta(i)-beta(i-1))^2)
e_FORM = 10^-6; % Covergence norm e_FORM = sqrt((xda(j)-xda(j-1))^2+(xdb(j)-xdb(j-1))^2)
%----------------------------------------------------------------%
i=0;  % Iteration number
R=[]; %Resistance vector (increases for every RSM-iteration)
b_vector_2 = []; %Vector containing the coefficients from least squares calculation from previous RSM-iteraions
beta=[];
alfa1=[];
alfa2=[];
alfa3=[];
alfa4=[];
alfa5=[];
x1={}; x2={}; x3={}; x4={}; x5={}; u1={}; u2={}; u3={}; u4={}; u5={};
CONV=1;

while CONV >= e_RSM %Check for convergence
        i=i+1; %Update iteration number
        
        %1) Find sample points
        
        [fc, fy, Ec, e1y, N ,Es, epc3, epcu3, epsy, epsu] = RSM_sample(x1d(i),x2d(i),x3d(i),x4d(i),x5d(i),f,sigma_logc,sigma_logs,sigma_logE,sigma_c,sigma_s,sigma_E,sigma_e,sigma_N,fck);
        
        %2) Run analyses and extract resistances
        
        [Ri]=MNdiagram(fc,fy,Ec,e1y,N,Es,epcu3,epsy,epsu);
        
        %3) Append new resistances to the R-vector
        R=vertcat(R,Ri(1,:)');
        
        %4) Run RSM
        [b_vector_2(:,i),a_vector] = RSM_generation(R,x1d,x2d,x3d,x4d,x5d,f,sigma_logc,sigma_logs,sigma_logE,sigma_c,sigma_s,sigma_E,sigma_e,sigma_N,fck);
         
        %5) Run FORM
        [x1d(i+1),x2d(i+1),x3d(i+1),x4d(i+1),x5d(i+1),beta(i),alfa1(i),alfa2(i),alfa3(i),alfa4(i),alfa5(i),x1{i},x2{i},x3{i},x4{i},x5{i},u1{i},u2{i},u3{i},u4{i},u5{i},A0{i},A1{i},A2{i},A3{i},A4{i},A5{i},B1{i},B2{i},B3{i},B4{i},B5{i},Pf(i),A0_SORM{i}] = SORM(mu_logc,mu_logs,mu_logE,mu_e,mu_N,b_vector_2(:,i),sigma_logc,sigma_logs,sigma_logE,sigma_e,sigma_N,x1d(i),x2d(i),x3d(i),x4d(i),x5d(i));
        if i==1
            CONV=1;
        else
            CONV=sqrt((beta(i)-beta(i-1))^2);
        end      
end   
fprintf('Beta: %6.6f \n',beta(end))
fprintf('Design point fcd: %6.2f\n',x1d(i+1))
fprintf('Design point fyd: %6.2f\n',x2d(i+1))
fprintf('Number of RSM-iterations: %6.2f\n',i)
Pf(end)