% LOAD DISTRIBUTION FIT - hard coding
clear all
close all

%-------------------------Intro-------------------------------------------%
%This script plots assumed lognormal PDFs for the load capacity given from
%a number of NLFEA RSM-FORM, as well as for the load capacity from
%experimental results from IABSE. Statistical uncertainty due to a small
%number of samples has not been considered!
%-------------------------------------------------------------------------%

% Run RSM_FORM for different load levels, or use results of column A: 
FORCE = [230 260 290 320 350 380 410 450 470 500 530];
PF_F = [0.0000 0.0021 0.0185 0.1159 0.2619 0.4601 0.6370 0.8114 0.87040 0.9285 0.9608];
%.................................CDF.....................................%
figure(1)
hold on
CDF = plot(FORCE,PF_F,'k:o');
% Finding lognormal fit
x = 200:650;
xp = FORCE; p = PF_F; prms = @(b,x) logncdf(x,b(1),b(2));
init_prms = interp1(p, xp, [0.5  0.025]);
B0 = [log(init_prms(1))  -diff(init_prms)/init_prms(1)];
B = nlinfit(xp,p,prms,B0);
lncdfit = prms(B,x); logplot = plot(x, lncdfit, '-b');

% Formatting
xlab = xlabel('Load levels (kN)');
ylab = ylabel('Probability of failure');
leg = legend('Pf points from NLFEA RSM-FORM','Lognormal fitted CDF');
set(logplot,'linewidth',1);
set(CDF,'linewidth',1); set(CDF,'markersize',7); %xticks(FORCE);
set(xlab,'fontsize',12); set(ylab,'fontsize',12); set(leg,'fontsize',12);
hold off

%.................................PDF.....................................%
figure(2)
hold on
% Modelled results R
pdf_points=lognpdf(x,B(1),B(2));
PDF = plot(x, pdf_points,'b');
    % transformed 
m_R = B(1); v_R = B(2);
mu_R = exp(m_R+v_R^2/2);
sigma_R = mu_R*sqrt(exp(v_R^2)-1); 

% Experimental results E from IABSE
E = [269 294 309 324 324 332];
n=length(E);
    % lognormal distribution 
log_E=log(E);
m_E=mean(log_E);
v_E=sqrt((1/(n-1))*sum((log_E-m_E).^2)); %- prosjektering lecture note 10
    % plot
x_e=200:500;
pdf_epoints = lognpdf(x_e,m_E,v_E);
E_PDF = plot(x_e,pdf_epoints,'k');
    % transformed
mu_E = exp(m_E+v_E^2/2);
sigma_E = exp(m_E+v_E^2/2)*sqrt(exp(v_E^2)-1); 

% Formatting
xlab = xlabel('Load (kN)');
ylab = ylabel('Probability density');
leg = legend('Modelled capacity, Lognormal','Experimental results, Lognormal');
set(PDF,'linewidth',1); set(E_PDF,'linewidth',1); 
set(xlab,'fontsize',12); set(ylab,'fontsize',12); set(leg,'fontsize',12);
%xticks(FORCE);


hold off
